@@ -1213,8 +1213,8 @@ char Vt102Emulation::getErase() const
 {
   KeyboardTranslator::Entry entry = _keyTranslator->findEntry(
                                             Qt::Key_Backspace,
-                                            nullptr,
-                                            nullptr);
+                                            Qt::NoModifier);
+
   if ( entry.text().count() > 0 )
       return entry.text()[0];
   else
@@ -1263,7 +1263,7 @@ void Vt102Emulation::scan_buffer_report() {
 
 void Vt102Emulation::ReportErrorToken()
 {
-#ifndef NDEBUG
-  printf("undecodable "); scan_buffer_report();
-#endif
+  // #ifndef NDEBUG
+  //   printf("undecodable "); scan_buffer_report();
+  // #endif
 }
