@@ -282,9 +282,9 @@ QConsolePrivate::QConsolePrivate (QWinTerminalImpl* parent, const QString& cmd)
   : q (parent), m_command (cmd), m_auto_scroll (true), m_cursorBlinking (false),
     m_hasBlinkingCursor (true), m_cursorType (BlockCursor),
     m_beginSelection (0, 0), m_endSelection (0, 0), m_settingSelection (false),
-    m_process (NULL), m_inWheelEvent (false)
+    m_process (nullptr), m_inWheelEvent (false)
 {
-  log (NULL);
+  log (nullptr);
 
   // Possibly detach from any existing console
   log ("Detaching from existing console (if any)...\n");
@@ -299,7 +299,7 @@ QConsolePrivate::QConsolePrivate (QWinTerminalImpl* parent, const QString& cmd)
 
   // Create new (hidden) console
   hOrigSta = GetProcessWindowStation ();
-  hNewSta = CreateWindowStation (NULL, 0, GENERIC_ALL, NULL);
+  hNewSta = CreateWindowStation (nullptr, 0, GENERIC_ALL, nullptr);
   log ("Current Windows station: %p.\nNew Windows station: %p.\n", hOrigSta,
        hNewSta);
   if (! SetProcessWindowStation (hNewSta))
@@ -328,9 +328,9 @@ QConsolePrivate::QConsolePrivate (QWinTerminalImpl* parent, const QString& cmd)
 
   log ("POSIX standard streams created.\n");
 
-  setvbuf (stdin, NULL, _IONBF, 0);
-  setvbuf (stdout, NULL, _IONBF, 0);
-  setvbuf (stderr, NULL, _IONBF, 0);
+  setvbuf (stdin, nullptr, _IONBF, 0);
+  setvbuf (stdout, nullptr, _IONBF, 0);
+  setvbuf (stderr, nullptr, _IONBF, 0);
 
   log ("POSIX standard stream buffers adjusted.\n");
 
@@ -390,13 +390,13 @@ QConsolePrivate::QConsolePrivate (QWinTerminalImpl* parent, const QString& cmd)
       SetConsoleOutputCP (65001);
     }
 
-  // Choose 15 (0xF) as index into the Windows console color map for the
-  // background and 0 (0x0) as the index for the foreground.  This
+  // Choose 0 (0x0) as index into the Windows console color map for the
+  // background and 7 (0x7) as the index for the foreground.  This
   // selection corresponds to the indices used in the foregroundColor,
   // setForegroundColor, backgroundColor, and SetBackgroundColor
   // functions.
 
-  SetConsoleTextAttribute (m_stdOut, 0xF0);
+  SetConsoleTextAttribute (m_stdOut, 0x07);
 
   // Defaults.
   setBackgroundColor (Qt::white);
@@ -408,8 +408,6 @@ QConsolePrivate::QConsolePrivate (QWinTerminalImpl* parent, const QString& cmd)
   QPalette palette (backgroundColor ());
   m_consoleView->setPalette (palette);
 
-  m_consoleView->setAutoFillBackground (true);
-
   m_consoleView->setFont (m_font);
   parent->setFocusPolicy (Qt::StrongFocus);
   parent->winId ();
@@ -581,12 +579,12 @@ void QConsolePrivate::clearSelection (void)
 
 QColor QConsolePrivate::backgroundColor (void) const
 {
-  return m_colors[15];
+  return m_colors[0];
 }
 
 QColor QConsolePrivate::foregroundColor (void) const
 {
-  return m_colors[0];
+  return m_colors[7];
 }
 
 QColor QConsolePrivate::selectionColor (void) const
@@ -601,15 +599,16 @@ QColor QConsolePrivate::cursorColor (void) const
 
 void QConsolePrivate::setBackgroundColor (const QColor& color)
 {
-  m_colors[15] = color;
+  m_colors[0] = color;
 
   QPalette palette (color);
+  palette.setColor(QPalette::Base, color);
   m_consoleView->setPalette (palette);
 }
 
 void QConsolePrivate::setForegroundColor (const QColor& color)
 {
-  m_colors[0] = color;
+  m_colors[7] = color;
 }
 
 void QConsolePrivate::setSelectionColor (const QColor& color)
@@ -1340,14 +1339,14 @@ void QConsolePrivate::startCommand (void)
       si.cb = sizeof (si);
       ZeroMemory (&pi, sizeof (pi));
 
-      if (CreateProcessW (NULL,
+      if (CreateProcessW (nullptr,
                           (LPWSTR)cmd.unicode (),
-                          NULL,
-                          NULL,
+                          nullptr,
+                          nullptr,
                           TRUE,
                           0,
-                          NULL,
-                          NULL,
+                          nullptr,
+                          nullptr,
                           &si,
                           &pi))
         {
@@ -1355,7 +1354,7 @@ void QConsolePrivate::startCommand (void)
           m_process = pi.hProcess;
           WaitForSingleObject (m_process, INFINITE);
           CloseHandle (m_process);
-          m_process = NULL;
+          m_process = nullptr;
         }
     }
 }
@@ -1557,6 +1556,7 @@ void QWinTerminalImpl::viewPaintEvent (QConsoleView* w, QPaintEvent* event)
   int ch = d->m_charSize.height ();
 
   QRect updateRect = event->rect ();
+  p.fillRect(updateRect, QBrush(d->backgroundColor()));
 
   int cx1 = updateRect.left () / cw;
   int cy1 = updateRect.top () / ch;
