@@ -1,47 +1,55 @@
-/*
-
-Copyright (C) 2011-2018 Jacob Dawid
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2011-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_files_dock_widget_h)
 #define octave_files_dock_widget_h 1
 
-#include <QListView>
+#include <QAction>
+#include <QComboBox>
 #include <QDate>
-#include <QObject>
-#include <QWidget>
-#include <QListWidget>
 #include <QFileSystemModel>
+#include <QList>
+#include <QListView>
+#include <QListWidget>
+#include <QMouseEvent>
+#include <QObject>
+#include <QSignalMapper>
 #include <QToolBar>
 #include <QToolButton>
-#include <QVBoxLayout>
-#include <QAction>
 #include <QTreeView>
-#include <QMouseEvent>
-#include <QSignalMapper>
+#include <QVBoxLayout>
+#include <QWidget>
 
-#include <QComboBox>
 #include "octave-dock-widget.h"
 
+class octave_value_list;
+
 namespace octave
 {
+  class base_qobject;
+
   //!  Dock widget to display files in the current directory.
 
   class files_dock_widget : public octave_dock_widget
@@ -50,10 +58,49 @@ namespace octave
 
   public:
 
-    files_dock_widget (QWidget *parent = nullptr);
+    files_dock_widget (QWidget *parent, base_qobject& oct_qobj);
 
     ~files_dock_widget (void) = default;
 
+  signals:
+
+    //! Emitted, whenever the user requested to open a file.
+
+    void open_file (const QString& fileName);
+
+    //! Emitted, whenever the currently displayed directory changed.
+
+    void displayed_directory_changed (const QString& dir);
+
+    //! Emitted, whenever the user requested to load a file in the text editor.
+
+    void load_file_signal (const QString& fileName);
+
+    //! Emitted, whenever the user requested to open an unknown type file.
+
+    void open_any_signal (const QString& fileName);
+
+    //! Emitted, whenever the user requested to run a file.
+
+    void run_file_signal (const QFileInfo& info);
+
+    //! Emitted, whenever wants to search for a file .
+
+    void find_files_signal (const QString& startdir);
+
+    //! Emitted, whenever the user removes or renames a file.
+
+    void file_remove_signal (const QString& old_name, const QString& new_name);
+
+    //! Emitted, when a file or directory is renamed.
+
+    void file_renamed_signal (bool);
+
+    //! Emitted, when the path has to be modified
+
+    void modify_path_signal (const octave_value_list& dir_list,
+                             bool rm, bool subdirs);
+
   public slots:
 
     //! Slot for handling a change in directory via double click.
@@ -86,7 +133,7 @@ namespace octave
 
     //! Tells the widget to react on changed settings.
 
-    void notice_settings (const QSettings *settings);
+    void notice_settings (const gui_settings *settings);
 
     void save_settings (void);
 
@@ -112,6 +159,10 @@ namespace octave
     void contextmenu_newfile (bool);
     void contextmenu_newdir (bool);
     void contextmenu_setcurrentdir (bool);
+    void contextmenu_add_to_path (bool, bool rm=false, bool subdirs=false);
+    void contextmenu_add_to_path_subdirs (bool);
+    void contextmenu_rm_from_path (bool);
+    void contextmenu_rm_from_path_subdirs (bool);
     void contextmenu_findfiles (bool);
     //!@}
 
@@ -131,40 +182,19 @@ namespace octave
     void selectAll ();
     //!@}
 
-  signals:
-
-    //! Emitted, whenever the user requested to open a file.
-
-    void open_file (const QString& fileName);
-
-    //! Emitted, whenever the currently displayed directory changed.
-
-    void displayed_directory_changed (const QString& dir);
-
-    //! Emitted, whenever the user requested to load a file.
-
-    void load_file_signal (const QString& fileName);
-
-    //! Emitted, whenever the user requested to run a file.
-
-    void run_file_signal (const QFileInfo& info);
-
-    //! Emitted, whenever wants to search for a file .
-
-    void find_files_signal (const QString& startdir);
-
-    //! Emitted, whenever the user removes or renames a file.
-
-    void file_remove_signal (const QString& old_name, const QString& new_name);
-
-    //! Emitted, when a file or directory is renamed.
-
-    void file_renamed_signal (bool);
-
   private:
 
+    //! Get currently selected QFileInfo object.
+
+    QList<QFileInfo> get_selected_items_info (bool);
+
+    //! Process new file/directory actions
+
     void process_new_file (const QString& parent_name);
     void process_new_dir (const QString& parent_name);
+
+    //! Process setting current dir or find in files
+
     void process_set_current_dir (const QString& parent_name);
     void process_find_files (const QString& dir_name);
 
@@ -202,6 +232,7 @@ namespace octave
 
     QStringList m_columns_shown;
     QStringList m_columns_shown_keys;
+    QList <QVariant> m_columns_shown_defs;
     QSignalMapper *m_sig_mapper;
   };
 }
