@@ -1,25 +1,29 @@
 // %NO_EDIT_WARNING%
-/*
 
-Copyright (C) 1996-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -107,12 +111,8 @@ namespace octave
 
     const char *DEFS = %OCTAVE_CONF_DEFS%;
 
-    const char *DL_LD = %OCTAVE_CONF_DL_LD%;
-
     const char *DL_LDFLAGS = %OCTAVE_CONF_DL_LDFLAGS%;
 
-    const char *DL_LIBS = %OCTAVE_CONF_DL_LIBS%;
-
     const char *EXEEXT = %OCTAVE_CONF_EXEEXT%;
 
     const char *GCC_VERSION = %OCTAVE_CONF_GCC_VERSION%;
@@ -173,12 +173,16 @@ namespace octave
 
     const char *INCLUDEDIR = %OCTAVE_CONF_INCLUDEDIR%;
 
+    const char *KLU_CPPFLAGS = %OCTAVE_CONF_KLU_CPPFLAGS%;
+
+    const char *KLU_LDFLAGS = %OCTAVE_CONF_KLU_LDFLAGS%;
+
+    const char *KLU_LIBS = %OCTAVE_CONF_KLU_LIBS%;
+
     const char *LAPACK_LIBS = %OCTAVE_CONF_LAPACK_LIBS%;
 
     const char *LDFLAGS = %OCTAVE_CONF_LDFLAGS%;
 
-    const char *LD_CXX = %OCTAVE_CONF_LD_CXX%;
-
     const char *LD_STATIC_FLAG = %OCTAVE_CONF_LD_STATIC_FLAG%;
 
     const char *LEXLIB = %OCTAVE_CONF_LEXLIB%;
@@ -223,14 +227,10 @@ namespace octave
 
     const char *OPENGL_LIBS = %OCTAVE_CONF_OPENGL_LIBS%;
 
-    const char *OSMESA_CPPFLAGS = %OCTAVE_CONF_OSMESA_CPPFLAGS%;
-
-    const char *OSMESA_LDFLAGS = %OCTAVE_CONF_OSMESA_LDFLAGS%;
-
-    const char *OSMESA_LIBS = %OCTAVE_CONF_OSMESA_LIBS%;
-
     const char *PCRE_CPPFLAGS = %OCTAVE_CONF_PCRE_CPPFLAGS%;
 
+    const char *PCRE_LDFLAGS = %OCTAVE_CONF_PCRE_LDFLAGS%;
+
     const char *PCRE_LIBS = %OCTAVE_CONF_PCRE_LIBS%;
 
     const char *PREFIX = %OCTAVE_CONF_PREFIX%;
@@ -257,23 +257,39 @@ namespace octave
 
     const char *QT_LIBS = %OCTAVE_CONF_QT_LIBS%;
 
+    const char *QT_OPENGL_LIBS = %OCTAVE_CONF_QT_OPENGL_LIBS%;
+
     const char *RANLIB = %OCTAVE_CONF_RANLIB%;
 
     const char *RDYNAMIC_FLAG = %OCTAVE_CONF_RDYNAMIC_FLAG%;
 
     const char *READLINE_LIBS = %OCTAVE_CONF_READLINE_LIBS%;
 
-    const char *SED = %OCTAVE_CONF_SED%;
-
     const char *SHARED_LIBS = %OCTAVE_CONF_SHARED_LIBS%;
 
-    const char *SH_LD = %OCTAVE_CONF_SH_LD%;
-
     const char *SH_LDFLAGS = %OCTAVE_CONF_SH_LDFLAGS%;
 
     const char *STATIC_LIBS = %OCTAVE_CONF_STATIC_LIBS%;
 
-    const char *SUITESPARSE_CONFIG_LIBS = %OCTAVE_CONF_SUITESPARSE_CONFIG_LIBS%;
+    const char *SUITESPARSECONFIG_LIBS = %OCTAVE_CONF_SUITESPARSECONFIG_LIBS%;
+
+    const char *SUNDIALS_IDA_CPPFLAGS = %OCTAVE_CONF_SUNDIALS_IDA_CPPFLAGS%;
+
+    const char *SUNDIALS_IDA_LDFLAGS = %OCTAVE_CONF_SUNDIALS_IDA_LDFLAGS%;
+
+    const char *SUNDIALS_IDA_LIBS = %OCTAVE_CONF_SUNDIALS_IDA_LIBS%;
+
+    const char *SUNDIALS_NVECSERIAL_CPPFLAGS = %OCTAVE_CONF_SUNDIALS_NVECSERIAL_CPPFLAGS%;
+
+    const char *SUNDIALS_NVECSERIAL_LDFLAGS = %OCTAVE_CONF_SUNDIALS_NVECSERIAL_LDFLAGS%;
+
+    const char *SUNDIALS_NVECSERIAL_LIBS = %OCTAVE_CONF_SUNDIALS_NVECSERIAL_LIBS%;
+
+    const char *SUNDIALS_SUNLINSOLKLU_CPPFLAGS = %OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_CPPFLAGS%;
+
+    const char *SUNDIALS_SUNLINSOLKLU_LDFLAGS = %OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LDFLAGS%;
+
+    const char *SUNDIALS_SUNLINSOLKLU_LIBS = %OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LIBS%;
 
     const char *TERM_LIBS = %OCTAVE_CONF_TERM_LIBS%;
 
