@@ -1,31 +1,34 @@
-/*
-
-Copyright (C) 1999-2018 John W. Eaton
-Copyright (C) 2009-2010 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1999-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_Cell_h)
 #define octave_Cell_h 1
 
 #include "octave-config.h"
 
+#include <list>
 #include <string>
 
 #include "Array.h"
@@ -40,8 +43,13 @@ Cell : public Array<octave_value>
 {
 public:
 
-  Cell (void)
-    : Array<octave_value> (dim_vector (0, 0)) { }
+  Cell (void) = default;
+
+  Cell (const Cell& c) = default;
+
+  Cell& operator = (const Cell& c) = default;
+
+  ~Cell (void) = default;
 
   Cell (const octave_value& val)
     : Array<octave_value> (dim_vector (1, 1), val) { }
@@ -83,13 +91,12 @@ public:
       }
   }
 
+  Cell (const std::list<std::string>& sl);
+
   Cell (const Array<std::string>& sa);
 
   Cell (const dim_vector& dv, const string_vector& sv, bool trim = false);
 
-  Cell (const Cell& c)
-    : Array<octave_value> (c) { }
-
   bool iscellstr (void) const;
 
   Array<std::string> cellstr_value (void) const;
