@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2004-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2004-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -598,8 +601,6 @@ bitshift (10, [-2, -1, 0, 1, 2])
       int64_t mask = max_mantissa_value<double> ();
       if (nbits < bits_in_mantissa)
         mask = mask >> (bits_in_mantissa - nbits);
-      else if (nbits < 1)
-        mask = 0;
       int bits_in_type = sizeof (double)
                          * std::numeric_limits<unsigned char>::digits;
       NDArray m = m_arg.array_value ();
@@ -629,8 +630,6 @@ bitshift (10, [-2, -1, 0, 1, 2])
       int64_t mask = max_mantissa_value<float> ();
       if (nbits < bits_in_mantissa)
         mask = mask >> (bits_in_mantissa - nbits);
-      else if (nbits < 1)
-        mask = 0;
       int bits_in_type = sizeof (float)
                          * std::numeric_limits<unsigned char>::digits;
       FloatNDArray m = m_arg.float_array_value ();
@@ -660,13 +659,27 @@ DEFUN (flintmax, args, ,
 @deftypefn  {} {} flintmax ()
 @deftypefnx {} {} flintmax ("double")
 @deftypefnx {} {} flintmax ("single")
+@deftypefnx {} {} flintmax (@var{var})
 Return the largest integer that can be represented consecutively in a
 floating point value.
 
-The default class is @qcode{"double"}, but @qcode{"single"} is a valid
-option.  On IEEE 754 compatible systems, @code{flintmax} is
-@w{@math{2^{53}}} for @qcode{"double"} and @w{@math{2^{24}}} for
-@qcode{"single"}.
+The input is either a string specifying a floating point type, or it is an
+existing floating point variable @var{var}.
+
+The default type is @qcode{"double"}, but @qcode{"single"} is a valid option.
+On IEEE 754 compatible systems, @code{flintmax} is @w{@math{2^{53}}} for
+@qcode{"double"} and @w{@math{2^{24}}} for @qcode{"single"}.
+
+Example Code - query an existing variable
+
+@example
+@group
+x = single (1);
+flintmax (x)
+  @result{} 16777216
+@end group
+@end example
+
 @seealso{intmax, realmax, realmin}
 @end deftypefn */)
 {
@@ -677,7 +690,14 @@ option.  On IEEE 754 compatible systems, @code{flintmax} is
 
   std::string cname = "double";
   if (nargin == 1)
-    cname = args(0).xstring_value ("flintmax: argument must be a string");
+    {
+      if (args(0).is_string ())
+        cname = args(0).string_value ();
+      else if (args(0).isfloat ())
+        cname = args(0).class_name ();
+      else
+        error ("intmin: argument must be a string or floating point variable");
+    }
 
   if (cname == "double")
     return ovl (static_cast<double> (max_mantissa_value<double> () + 1));
@@ -692,46 +712,66 @@ option.  On IEEE 754 compatible systems, @code{flintmax} is
 %!assert (flintmax ("double"), 2^53)
 %!assert (flintmax ("single"), single (2^24))
 
-%!error flintmax (0)
+%!test
+%! x = single (1);
+%! assert (flintmax (x), single (16777216));
+
 %!error flintmax ("double", 0)
-%!error flintmax ("int32")
-%!error flintmax ("char")
+%!error <must be a string or floating point variable> flintmax (int8 (1))
+%!error <not defined for class 'int8'> flintmax ("int8")
+%!error <not defined for class 'char'> flintmax ("char")
 */
 
 DEFUN (intmax, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} intmax (@var{type})
-Return the largest integer that can be represented in an integer type.
+@deftypefn  {} {} intmax ()
+@deftypefnx {} {} intmax ("@var{type}")
+@deftypefnx {} {} intmax (@var{var})
+Return the largest integer that can be represented by a specific integer type.
 
-The variable @var{type} can be
+The input is either a string @qcode{"@var{type}"} specifying an integer type,
+or it is an existing integer variable @var{var}.
 
-@table @code
-@item int8
+Possible values for @var{type} are
+
+@table @asis
+@item @qcode{"int8"}
 signed 8-bit integer.
 
-@item int16
+@item @qcode{"int16"}
 signed 16-bit integer.
 
-@item int32
+@item @qcode{"int32"}
 signed 32-bit integer.
 
-@item int64
+@item @qcode{"int64"}
 signed 64-bit integer.
 
-@item uint8
+@item @qcode{"uint8"}
 unsigned 8-bit integer.
 
-@item uint16
+@item @qcode{"uint16"}
 unsigned 16-bit integer.
 
-@item uint32
+@item @qcode{"uint32"}
 unsigned 32-bit integer.
 
-@item uint64
+@item @qcode{"uint64"}
 unsigned 64-bit integer.
 @end table
 
-The default for @var{type} is @code{int32}.
+The default for @var{type} is @qcode{"int32"}.
+
+Example Code - query an existing variable
+
+@example
+@group
+x = int8 (1);
+intmax (x)
+  @result{} 127
+@end group
+@end example
+
 @seealso{intmin, flintmax}
 @end deftypefn */)
 {
@@ -742,7 +782,14 @@ The default for @var{type} is @code{int32}.
 
   std::string cname = "int32";
   if (nargin == 1)
-    cname = args(0).xstring_value ("intmax: argument must be a string");
+    {
+      if (args(0).is_string ())
+        cname = args(0).string_value ();
+      else if (args(0).isinteger ())
+        cname = args(0).class_name ();
+      else
+        error ("intmax: argument must be a string or integer variable");
+    }
 
   octave_value retval;
 
@@ -779,46 +826,66 @@ The default for @var{type} is @code{int32}.
 %!assert (intmax ("int64"),   int64 (2^63 - 1))
 %!assert (intmax ("uint64"), uint64 (2^64 - 1))
 
-%!error intmax (0)
+%!test
+%! x = int8 (1);
+%! assert (intmax (x), int8 (127));
+
 %!error intmax ("int32", 0)
-%!error intmax ("double")
-%!error intmax ("char")
+%!error <must be a string or integer variable> intmax (1.0)
+%!error <not defined for 'double' objects> intmax ("double")
+%!error <not defined for 'char' objects> intmax ("char")
 */
 
 DEFUN (intmin, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn {} {} intmin (@var{type})
-Return the smallest integer that can be represented in an integer type.
+@deftypefn  {} {} intmin ()
+@deftypefnx {} {} intmin ("@var{type}")
+@deftypefnx {} {} intmin (@var{var})
+Return the smallest integer that can be represented by a specific integer type.
 
-The variable @var{type} can be
+The input is either a string @qcode{"@var{type}"} specifying an integer type,
+or it is an existing integer variable @var{var}.
 
-@table @code
-@item int8
+Possible values for @var{type} are
+
+@table @asis
+@item @qcode{"int8"}
 signed 8-bit integer.
 
-@item int16
+@item @qcode{"int16"}
 signed 16-bit integer.
 
-@item int32
+@item @qcode{"int32"}
 signed 32-bit integer.
 
-@item int64
+@item @qcode{"int64"}
 signed 64-bit integer.
 
-@item uint8
+@item @qcode{"uint8"}
 unsigned 8-bit integer.
 
-@item uint16
+@item @qcode{"uint16"}
 unsigned 16-bit integer.
 
-@item uint32
+@item @qcode{"uint32"}
 unsigned 32-bit integer.
 
-@item uint64
+@item @qcode{"uint64"}
 unsigned 64-bit integer.
 @end table
 
-The default for @var{type} is @code{int32}.
+The default for @var{type} is @qcode{"int32"}.
+
+Example Code - query an existing variable
+
+@example
+@group
+x = int8 (1);
+intmin (x)
+  @result{} -128
+@end group
+@end example
+
 @seealso{intmax, flintmax}
 @end deftypefn */)
 {
@@ -829,7 +896,14 @@ The default for @var{type} is @code{int32}.
 
   std::string cname = "int32";
   if (nargin == 1)
-    cname = args(0).xstring_value ("intmin: argument must be a string");
+    {
+      if (args(0).is_string ())
+        cname = args(0).string_value ();
+      else if (args(0).isinteger ())
+        cname = args(0).class_name ();
+      else
+        error ("intmin: argument must be a string or integer variable");
+    }
 
   octave_value retval;
 
@@ -866,10 +940,14 @@ The default for @var{type} is @code{int32}.
 %!assert (intmin ("int64"),   int64 (-2^63))
 %!assert (intmin ("uint64"), uint64 (-2^64))
 
-%!error intmin (0)
+%!test
+%! x = int8 (1);
+%! assert (intmin (x), int8 (-128));
+
 %!error intmin ("int32", 0)
-%!error intmin ("double")
-%!error intmin ("char")
+%!error <must be a string or integer variable> intmin (1.0)
+%!error <not defined for 'double' objects> intmin ("double")
+%!error <not defined for 'char' objects> intmin ("char")
 */
 
 DEFUN (sizemax, args, ,
