@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 2007-2019 David Bateman
-Copyright (C) 2009 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2007-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -173,10 +175,10 @@ static void maybe_fill_table (void)
   REGISTER_OP_HANDLER (bsxfun_builtin_or, btyp_bool, boolNDArray, bsxfun_or);
 
   // Register power handlers.
-  bsxfun_handler_table[bsxfun_builtin_power][btyp_double] =
-    do_bsxfun_real_pow<NDArray, ComplexNDArray>;
-  bsxfun_handler_table[bsxfun_builtin_power][btyp_float] =
-    do_bsxfun_real_pow<FloatNDArray, FloatComplexNDArray>;
+  bsxfun_handler_table[bsxfun_builtin_power][btyp_double]
+    = do_bsxfun_real_pow<NDArray, ComplexNDArray>;
+  bsxfun_handler_table[bsxfun_builtin_power][btyp_float]
+    = do_bsxfun_real_pow<FloatNDArray, FloatComplexNDArray>;
 
   REGISTER_OP_HANDLER (bsxfun_builtin_power, btyp_complex, ComplexNDArray,
                        bsxfun_pow);
@@ -485,8 +487,8 @@ as the other array.
                           else
                             {
                               have_ComplexNDArray = true;
-                              result_ComplexNDArray =
-                                tmp(0).complex_array_value ();
+                              result_ComplexNDArray
+                                = tmp(0).complex_array_value ();
                               result_ComplexNDArray.resize (dvc);
                             }
                         }
@@ -495,15 +497,15 @@ as the other array.
                           if (tmp(0).isreal ())
                             {
                               have_FloatNDArray = true;
-                              result_FloatNDArray =
-                                tmp(0).float_array_value ();
+                              result_FloatNDArray
+                                = tmp(0).float_array_value ();
                               result_FloatNDArray.resize (dvc);
                             }
                           else
                             {
                               have_FloatComplexNDArray = true;
-                              result_FloatComplexNDArray =
-                                tmp(0).float_complex_array_value ();
+                              result_FloatComplexNDArray
+                                = tmp(0).float_complex_array_value ();
                               result_FloatComplexNDArray.resize (dvc);
                             }
                         }
@@ -544,8 +546,8 @@ as the other array.
                         result_NDArray.insert (tmp(0).array_value (), ra_idx);
                       else
                         {
-                          result_ComplexNDArray =
-                            ComplexNDArray (result_NDArray);
+                          result_ComplexNDArray
+                            = ComplexNDArray (result_NDArray);
                           result_ComplexNDArray.insert
                             (tmp(0).complex_array_value (), ra_idx);
                           have_NDArray = false;
@@ -565,8 +567,8 @@ as the other array.
                           (tmp(0).float_array_value (), ra_idx);
                       else
                         {
-                          result_FloatComplexNDArray =
-                            FloatComplexNDArray (result_FloatNDArray);
+                          result_FloatComplexNDArray
+                            = FloatComplexNDArray (result_FloatNDArray);
                           result_FloatComplexNDArray.insert
                             (tmp(0).float_complex_array_value (), ra_idx);
                           have_FloatNDArray = false;
