@@ -1,30 +1,33 @@
-/*
-
-Copyright (C) 2000-2016 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2000-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include <iostream>
+#include <iomanip>
 
 #include "filepos-wrappers.h"
 
@@ -82,7 +85,7 @@ c_file_ptr_buf::pbackfail (int_type c)
 }
 
 std::streamsize
-c_file_ptr_buf::xsputn (const char* s, std::streamsize n)
+c_file_ptr_buf::xsputn (const char *s, std::streamsize n)
 {
   if (f)
     return std::fwrite (s, 1, n, f);
@@ -160,7 +163,7 @@ c_file_ptr_buf::buf_close (void)
   if (f)
     {
       retval = cf (f);
-      f = 0;
+      f = nullptr;
     }
 
   return retval;
@@ -226,7 +229,7 @@ c_zfile_ptr_buf::pbackfail (int_type c)
 }
 
 std::streamsize
-c_zfile_ptr_buf::xsputn (const char* s, std::streamsize n)
+c_zfile_ptr_buf::xsputn (const char *s, std::streamsize n)
 {
   if (f)
     return gzwrite (f, s, n);
@@ -307,11 +310,10 @@ c_zfile_ptr_buf::buf_close (void)
   if (f)
     {
       retval = cf (f);
-      f = 0;
+      f = nullptr;
     }
 
   return retval;
 }
 
 #endif
-
