@@ -1,25 +1,27 @@
-/*
-
-Copyright (C) 1997-2018 David Bateman
-Copyright (C) 1996-1997 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -35,12 +37,6 @@ along with Octave; see the file COPYING.  If not, see
 
 // This function should be merged with Fifft.
 
-#if defined (HAVE_FFTW)
-#  define FFTSRC "@sc{fftw}"
-#else
-#  define FFTSRC "@sc{fftpack}"
-#endif
-
 static octave_value
 do_fft2 (const octave_value_list& args, const char *fcn, int type)
 {
@@ -182,7 +178,7 @@ of @var{A} is treated separately.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! M = 16;
 %! N = 8;
 %!
@@ -201,7 +197,7 @@ of @var{A} is treated separately.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! M = 12;
 %! N = 7;
 %!
@@ -223,7 +219,7 @@ of @var{A} is treated separately.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! M = 16;
 %! N = 8;
 %!
@@ -242,7 +238,7 @@ of @var{A} is treated separately.
 ## Author: David Billinghurst (David.Billinghurst@riotinto.com.au)
 ##         Comalco Research and Technology
 ##         02 May 2000
-%!test
+%!testif HAVE_FFTW
 %! M = 12;
 %! N = 7;
 %!
