@@ -1,26 +1,27 @@
-/*
-
-Copyright (C) 1996-2019 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
-
-// Author: James R. Van Zandt <jrv@vanzandt.mv.com>
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -51,7 +52,6 @@ along with Octave; see the file COPYING.  If not, see
 #include "str-vec.h"
 
 #include "Cell.h"
-#include "call-stack.h"
 #include "defaults.h"
 #include "defun.h"
 #include "error.h"
@@ -65,11 +65,12 @@ along with Octave; see the file COPYING.  If not, see
 #include "oct-map.h"
 #include "ov-cell.h"
 #include "ov-class.h"
-#include "ov-fcn-inline.h"
 #include "ov.h"
 #include "ovl.h"
 #include "pager.h"
 #include "parse.h"
+#include "pt-eval.h"
+#include "stack-frame.h"
 #include "sysdep.h"
 #include "unwind-prot.h"
 #include "utils.h"
@@ -847,7 +848,7 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
         if (! is)
           goto data_read_error;
 
-        // Octave can handle both "/" and "\" as a directory seperator
+        // Octave can handle both "/" and "\" as a directory separator
         // and so can ignore the separator field of m0.  I think the
         // sentinel field is also save to ignore.
         octave_scalar_map m0 = tc2.scalar_map_value ();
@@ -860,12 +861,16 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
         if (ftype == "simple" || ftype == "scopedfunction")
           {
             if (fpath.empty ())
-              // We have a builtin function
-              tc = make_fcn_handle (fname);
+              {
+                octave::tree_evaluator& tw = interp.get_evaluator ();
+
+                // We have a builtin function
+                // XXX FCN_HANDLE: SIMPLE/SCOPED
+                tc = tw.make_fcn_handle (fname);
+              }
             else
               {
-                std::string mroot =
-                  m0.contents ("matlabroot").string_value ();
+                std::string mroot = m0.contents ("matlabroot").string_value ();
 
                 if ((fpath.length () >= mroot.length ())
                     && fpath.substr (0, mroot.length ()) == mroot
@@ -896,6 +901,7 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
                                                         "", "", fname);
 
                         if (ov_fcn.is_defined ())
+                          // XXX FCN_HANDLE: SIMPLE/SCOPED
                           tc = octave_value (new octave_fcn_handle (ov_fcn, fname));
                       }
                     else
@@ -910,8 +916,7 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
 
                         octave::directory_path p (lp.system_path ());
 
-                        str =
-                          octave::sys::env::make_absolute (p.find_first_of (names));
+                        str = octave::sys::env::make_absolute (p.find_first_of (names));
 
                         size_t xpos
                           = str.find_last_of (octave::sys::file_ops::dir_sep_chars ());
@@ -923,11 +928,13 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
                                                         "", "", fname);
 
                         if (ov_fcn.is_defined ())
+                          // XXX FCN_HANDLE: SIMPLE/SCOPED
                           tc = octave_value (new octave_fcn_handle (ov_fcn, fname));
                         else
                           {
-                            warning ("load: can't find the file %s",
-                                     fpath.c_str ());
+                            warning_with_id ("Octave:load:file-not-found",
+                                             "load: can't find the file %s",
+                                             fpath.c_str ());
                             goto skip_ahead;
                           }
                       }
@@ -944,11 +951,13 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
                                                     "", "", fname);
 
                     if (ov_fcn.is_defined ())
+                      // XXX FCN_HANDLE: SIMPLE/SCOPED
                       tc = octave_value (new octave_fcn_handle (ov_fcn, fname));
                     else
                       {
-                        warning ("load: can't find the file %s",
-                                 fpath.c_str ());
+                        warning_with_id ("Octave:load:file-not-found",
+                                         "load: can't find the file %s",
+                                         fpath.c_str ());
                         goto skip_ahead;
                       }
                   }
@@ -956,7 +965,8 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
           }
         else if (ftype == "nested")
           {
-            warning ("load: can't load nested function");
+            warning_with_id ("Octave:load:unsupported-type",
+                             "load: can't load nested function");
             goto skip_ahead;
           }
         else if (ftype == "anonymous")
@@ -969,36 +979,44 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
             m2 = subsys_ov.scalar_map_value ();
             m2 = m2.contents ("MCOS").scalar_map_value ();
             tc2 = m2.contents ("MCOS").cell_value ()(1 + off).cell_value ()(1);
-            m2 = tc2.scalar_map_value ();
 
-            octave::unwind_protect_safe frame;
+            octave::stack_frame::local_vars_map local_vars;
 
-            // Set up temporary scope to use for evaluating the text
-            // that defines the anonymous function.
-
-            octave::symbol_table& symtab = interp.get_symbol_table ();
-
-            octave::symbol_scope local_scope;
-
-            symtab.set_scope (local_scope);
-
-            octave::call_stack& cs = interp.get_call_stack ();
-            cs.push (local_scope, 0);
-            frame.add_method (cs, &octave::call_stack::pop);
-
-            if (m2.nfields () > 0)
+            if (! tc2.isempty ())
               {
-                octave_value tmp;
+                m2 = tc2.scalar_map_value ();
 
-                for (auto p0 = m2.begin (); p0 != m2.end (); p0++)
+                if (m2.nfields () > 0)
                   {
-                    std::string key = m2.key (p0);
-                    octave_value val = m2.contents (p0);
+                    octave_value tmp;
 
-                    local_scope.assign (key, val, 0);
+                    for (auto p0 = m2.begin (); p0 != m2.end (); p0++)
+                      {
+                        std::string key = m2.key (p0);
+                        octave_value val = m2.contents (p0);
+
+                        local_vars[key] = val;
+                      }
                   }
               }
 
+            // Set up temporary scope to use for evaluating the text
+            // that defines the anonymous function so that we don't
+            // pick up values of random variables that might be in the
+            // current scope.
+
+            octave::tree_evaluator& tw = interp.get_evaluator ();
+            tw.push_dummy_scope ("read_mat5_binary_element");
+
+            octave::unwind_action act ([&tw] () { tw.pop_scope (); });
+
+            // FIXME: If evaluation of the string gives us an anonymous
+            // function handle object, then why extract the function and
+            // create a new anonymous function object?  Why not just
+            // attach the workspace values to the object returned by
+            // eval_string?  This code is also is duplicated in
+            // anon_fcn_handle::parse_anon_fcn_handle.
+
             int parse_status;
             octave_value anon_fcn_handle
               = interp.eval_string (fname.substr (4), true, parse_status);
@@ -1006,15 +1024,13 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
             if (parse_status != 0)
               error ("load: failed to load anonymous function handle");
 
-            octave_fcn_handle *fh =
-              anon_fcn_handle.fcn_handle_value ();
+            octave_fcn_handle *fh = anon_fcn_handle.fcn_handle_value ();
 
             if (! fh)
               error ("load: failed to load anonymous function handle");
 
-            tc = new octave_fcn_handle (fh->fcn_val (), "@<anonymous>");
-
-            frame.run ();
+            // XXX FCN_HANDLE: ANONYMOUS
+            tc = octave_value (new octave_fcn_handle (fh->fcn_val (), local_vars));
           }
         else
           error ("load: invalid function handle type");
@@ -1181,58 +1197,50 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
 
         if (isclass)
           {
-            if (classname == "inline")
+            octave::cdef_manager& cdm = interp.get_cdef_manager ();
+
+            if (cdm.find_class (classname, false, true).ok ())
               {
-                // inline is not an object in Octave but rather an
-                // overload of a function handle.  Special case.
-                tc =
-                  new octave_fcn_inline (m.contents ("expr")(0).string_value (),
-                                         m.contents ("args")(0).string_value ());
+                tc = m;
+                warning_with_id ("Octave:load:classdef-to-struct",
+                                 "load: classdef element has been converted to a struct");
               }
             else
               {
-                cdef_manager& cdm = interp.get_cdef_manager ();
+                octave_class *cls
+                  = new octave_class (m, classname,
+                                      std::list<std::string> ());
 
-                if (cdm.find_class (classname, false, true).ok ())
+                if (cls->reconstruct_exemplar ())
                   {
-                    tc = m;
-                    warning ("load: classdef element has been converted to a struct");
+
+                    if (! cls->reconstruct_parents ())
+                      warning_with_id ("Octave:load:classdef-object-inheritance",
+                                       "load: unable to reconstruct object inheritance");
+
+                    tc = cls;
+
+                    octave::load_path& lp = interp.get_load_path ();
+
+                    if (lp.find_method (classname, "loadobj") != "")
+                      {
+                        try
+                          {
+                            octave_value_list tmp = octave::feval ("loadobj", tc, 1);
+
+                            tc = tmp(0);
+                          }
+                        catch (const octave::execution_exception&)
+                          {
+                            goto data_read_error;
+                          }
+                      }
                   }
                 else
                   {
-                    octave_class *cls
-                      = new octave_class (m, classname,
-                                          std::list<std::string> ());
-
-                    if (cls->reconstruct_exemplar ())
-                      {
-
-                        if (! cls->reconstruct_parents ())
-                          warning ("load: unable to reconstruct object inheritance");
-
-                        tc = cls;
-
-                        octave::load_path& lp = interp.get_load_path ();
-
-                        if (lp.find_method (classname, "loadobj") != "")
-                          {
-                            try
-                              {
-                                octave_value_list tmp = octave::feval ("loadobj", tc, 1);
-
-                                tc = tmp(0);
-                              }
-                            catch (const octave::execution_exception&)
-                              {
-                                goto data_read_error;
-                              }
-                          }
-                      }
-                    else
-                      {
-                        tc = m;
-                        warning ("load: element has been converted to a structure");
-                      }
+                    tc = m;
+                    warning_with_id ("Octave:load:classdef-to-struct",
+                                     "load: element has been converted to a structure");
                   }
               }
           }
@@ -1426,7 +1434,8 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
                       }
 
                     if (found_big_char)
-                      warning ("load: can not read non-ASCII portions of UTF characters; replacing unreadable characters with '?'");
+                      warning_with_id ("Octave:load:unsupported-utf-char",
+                               "load: can not read non-ASCII portions of UTF characters; replacing unreadable characters with '?'");
                   }
                 else if (type == miUTF8)
                   {
@@ -1443,7 +1452,8 @@ read_mat5_binary_element (std::istream& is, const std::string& filename,
 
                     if (utf8_multi_byte)
                       {
-                        warning ("load: can not read multi-byte encoded UTF8 characters; replacing unreadable characters with '?'");
+                        warning_with_id ("Octave:load:unsupported-utf-char",
+                                         "load: can not read multi-byte encoded UTF8 characters; replacing unreadable characters with '?'");
                         for (octave_idx_type i = 0; i < n; i++)
                           {
                             unsigned char a
@@ -1474,7 +1484,8 @@ data_read_error:
   error ("load: trouble reading binary file '%s'", filename.c_str ());
 
 skip_ahead:
-  warning ("load: skipping over '%s'", retval.c_str ());
+  warning_with_id ("Octave:load:skip-unsupported-element",
+                   "load: skipping over '%s'", retval.c_str ());
   is.seekg (pos + static_cast<std::streamoff> (element_length));
   return read_mat5_binary_element (is, filename, swap, global, tc);
 }
@@ -1495,9 +1506,9 @@ read_mat5_binary_file_header (std::istream& is, bool& swap, bool quiet,
   is.read (reinterpret_cast<char *> (&magic), 2);
 
   if (magic == 0x4d49)
-    swap = 0;
+    swap = false;
   else if (magic == 0x494d)
-    swap = 1;
+    swap = true;
   else
     {
       if (! quiet)
@@ -1510,8 +1521,9 @@ read_mat5_binary_file_header (std::istream& is, bool& swap, bool quiet,
     version = ((version >> 8) & 0xff) + ((version & 0xff) << 8);
 
   if (version != 1 && ! quiet)
-    warning ("load: found version %d binary MAT file, "
-             "but only prepared for version 1", version);
+    warning_with_id ("Octave:load:unsupported-version",
+                     "load: found version %d binary MAT file, but only prepared for version 1",
+                     version);
 
   if (swap)
     swap_bytes<8> (&subsys_offset, 1);
@@ -1605,8 +1617,8 @@ write_mat5_array (std::ostream& os, const NDArray& m, bool save_as_floats)
     {
       if (m.too_large_for_float ())
         {
-          warning ("save: some values too large to save as floats --");
-          warning ("save: saving as doubles instead");
+          warning_with_id ("Octave:save:too-large-for-float",
+                           "save: some values too large to save as floats -- saving as doubles instead");
         }
       else
         st = LS_FLOAT;
@@ -2228,8 +2240,9 @@ write_mat5_sparse_index_vector (std::ostream& os,
 static void
 warn_dim_too_large (const std::string& name)
 {
-  warning ("save: skipping %s: dimension too large for MAT format",
-           name.c_str ());
+  warning_with_id ("Octave:save:dimension-too-large",
+                   "save: skipping %s: dimension too large for MAT format",
+                   name.c_str ());
 }
 
 // save the data from TC along with the corresponding NAME on stream
