@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2005-2018 David Bateman
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2005-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -153,8 +156,8 @@ LU@tie{}factorization.  Once the matrix has been factorized,
 
               if (mattyp.is_unknown () && autocomp)
                 {
-                  SparseComplexMatrix m =
-                    args(0).sparse_complex_matrix_value ();
+                  SparseComplexMatrix m
+                    = args(0).sparse_complex_matrix_value ();
 
                   mattyp = MatrixType (m);
                   args(0).matrix_type (mattyp);
@@ -266,7 +269,7 @@ LU@tie{}factorization.  Once the matrix has been factorized,
           if (nargin == 3
               && (str_typ == "upper" || str_typ == "lower"))
             {
-              const ColumnVector perm = args(2).vector_value ("matrix_type: Invalid permutation vector PERM");
+              const ColumnVector perm = args(2).xvector_value ("matrix_type: Invalid permutation vector PERM");
 
               octave_idx_type len = perm.numel ();
               dim_vector dv = args(0).dims ();
@@ -403,7 +406,7 @@ LU@tie{}factorization.  Once the matrix has been factorized,
 
           if (nargin == 3 && (str_typ == "upper" || str_typ == "lower"))
             {
-              const ColumnVector perm = args(2).vector_value ("matrix_type: Invalid permutation vector PERM");
+              const ColumnVector perm = args(2).xvector_value ("matrix_type: Invalid permutation vector PERM");
 
               octave_idx_type len = perm.numel ();
               dim_vector dv = args(0).dims ();
