@@ -1,32 +1,37 @@
-/*
-
-Copyright (C) 2012-2019 Iain Murray
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2012-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
-#include "defun.h"
 #include "nproc-wrapper.h"
 
+#include "defun.h"
+#include "error.h"
+
 DEFUN (nproc, args, ,
        doc: /* -*- texinfo -*-
 @deftypefn  {} {} nproc ()
@@ -54,7 +59,7 @@ same as @code{current}, but overridable through the
   if (nargin > 1)
     print_usage ();
 
-  octave_nproc_query query = OCTAVE_NPROC_CURRENT;
+  octave_nproc_query query = OCTAVE_NPROC_CURRENT_OVERRIDABLE;
 
   if (nargin == 1)
     {
@@ -81,6 +86,9 @@ same as @code{current}, but overridable through the
 %!assert (nproc ("all") >= 1)
 %!assert (nproc ("current") >= 1)
 
+## Test that "overridable" is the default
+%!assert (nproc ("overridable"), nproc ())
+
 %!test
 %! c = nproc ("current");
 %! unwind_protect
