@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1995-2019 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1995-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -48,7 +51,6 @@ along with Octave; see the file COPYING.  If not, see
 
 #include "build-env.h"
 #include "liboctinterp-build-info.h"
-#include "call-stack.h"
 #include "defaults.h"
 #include "defun.h"
 #include "error.h"
@@ -182,17 +184,11 @@ DEFUN (system, args, nargout,
 @deftypefnx {} {[@var{status}, @var{output}] =} system (@dots{})
 Execute a shell command specified by @var{string}.
 
-If the optional argument @var{type} is @qcode{"async"}, the process is
-started in the background and the process ID of the child process is
-returned immediately.  Otherwise, the child process is started and Octave
-waits until it exits.  If the @var{type} argument is omitted, it defaults to
-the value @qcode{"sync"}.
-
-If @var{system} is called with one or more output arguments, or if the
-optional argument @var{return_output} is true and the subprocess is started
+If @var{system} is called with one or more output arguments, or if the optional
+argument @var{return_output} is true and the subprocess is started
 synchronously, then the output from the command is returned as a variable.
-Otherwise, if the subprocess is executed synchronously, its output is sent
-to the standard output.  To send the output of a command executed with
+Otherwise, if the subprocess is executed synchronously, its output is sent to
+the standard output.  To send the output of a command executed with
 @code{system} through the pager, use a command like
 
 @example
@@ -213,25 +209,30 @@ printf ("%s\n", nthargout (2, "system", "cmd"));
 @end group
 @end example
 
-The @code{system} function can return two values.  The first is the
-exit status of the command and the second is any output from the
-command that was written to the standard output stream.  For example,
+If the optional argument @var{type} is @qcode{"async"}, the process is started
+in the background and the process ID of the child process is returned
+immediately.  Otherwise, the child process is started and Octave waits until it
+exits.  If the @var{type} argument is omitted, it defaults to the value
+@qcode{"sync"}.
+
+The @code{system} function can return two values.  The first is the exit status
+of the command and the second is any output from the command that was written
+to the standard output stream.  For example,
 
 @example
 [status, output] = system ("echo foo & exit 2");
 @end example
 
 @noindent
-will set the variable @var{output} to the string @samp{foo}, and the
-variable @var{status} to the integer @samp{2}.
+will set the variable @var{output} to the string @samp{foo}, and the variable
+@var{status} to the integer @samp{2}.
 
-For commands run asynchronously, @var{status} is the process id of the
-command shell that is started to run the command.
+For commands run asynchronously, @var{status} is the process id of the command
+shell that is started to run the command.
 
 The shell used for executing commands varies with operating system and is
 typically @file{/bin/sh} for UNIX systems and @nospell{@file{cmd.exe}} for
-Windows
-systems.
+Windows systems.
 @seealso{unix, dos}
 @end deftypefn */)
 {
@@ -285,6 +286,7 @@ systems.
   frame.add_fcn (restore_signal_mask, get_signal_mask ());
 
   octave_unblock_async_signals ();
+  octave_unblock_signal_by_name ("SIGTSTP");
 
   if (type == et_async)
     retval(0) = octave_async_system_wrapper (cmd_str.c_str ());
@@ -364,10 +366,10 @@ specified option.
            { "ENABLE_64", false },
 #endif
 
-#if defined (OCTAVE_ENABLE_ATOMIC_REFCOUNT)
-           { "ENABLE_ATOMIC_REFCOUNT", true },
+#if defined (OCTAVE_ENABLE_COMMAND_LINE_PUSH_PARSER)
+           { "ENABLE_COMMAND_LINE_PUSH_PARSER", true },
 #else
-           { "ENABLE_ATOMIC_REFCOUNT", false },
+           { "ENABLE_COMMAND_LINE_PUSH_PARSER", false },
 #endif
 
 #if defined (ENABLE_DOCS)
@@ -475,7 +477,6 @@ specified option.
            { "CXXFLAGS", octave::build_env::CXXFLAGS },
            { "CXXPICFLAG", octave::build_env::CXXPICFLAG },
            { "DEFS", octave::build_env::DEFS },
-           { "DL_LD", octave::build_env::DL_LD },
            { "DL_LDFLAGS", octave::build_env::DL_LDFLAGS },
            { "GCC_VERSION", octave::build_env::GCC_VERSION },
            { "GXX_VERSION", octave::build_env::GXX_VERSION },
@@ -508,7 +509,6 @@ specified option.
            { "HDF5_LIBS", octave::build_env::HDF5_LIBS },
            { "LAPACK_LIBS", octave::build_env::LAPACK_LIBS },
            { "LDFLAGS", octave::build_env::LDFLAGS },
-           { "LD_CXX", octave::build_env::LD_CXX },
            { "LD_STATIC_FLAG", octave::build_env::LD_STATIC_FLAG },
            { "LEX", octave::build_env::LEX },
            { "LEXLIB", octave::build_env::LEXLIB },
@@ -548,7 +548,6 @@ specified option.
            { "RDYNAMIC_FLAG", octave::build_env::RDYNAMIC_FLAG },
            { "READLINE_LIBS", octave::build_env::READLINE_LIBS },
            { "SHARED_LIBS", octave::build_env::SHARED_LIBS },
-           { "SH_LD", octave::build_env::SH_LD },
            { "SH_LDFLAGS", octave::build_env::SH_LDFLAGS },
            { "STATIC_LIBS", octave::build_env::STATIC_LIBS },
            { "SUITESPARSECONFIG_LIBS", octave::build_env::SUITESPARSECONFIG_LIBS },
