@@ -89,7 +89,7 @@ Return a structure describing the available audio input and output devices.
 
 The @var{devinfo} structure has two fields @qcode{"input"} and
 @qcode{"output"}.  The value of each field is a structure array with fields
-@qcode{"Name"}, @qcode{@nospell{"DriverVersion"}} and @qcode{"ID"} describing
+@qcode{"Name"}, @nospell{@qcode{"DriverVersion"}} and @qcode{"ID"} describing
 an audio device.
 
 If the optional argument @var{io} is 1, return information about input devices
@@ -103,7 +103,7 @@ corresponding device.
 If the optional argument @var{name} is provided, return the ID of the named
 device.
 
-If the optional argument @qcode{@nospell{"DriverVersion"}} is given, return the
+If the optional argument @nospell{@qcode{"DriverVersion"}} is given, return the
 name of the driver for the specified device.
 
 Given a sampling rate, bits per sample, and number of channels for an input or
@@ -2383,7 +2383,7 @@ Undocumented internal function.
     {
       // FIXME: Should be able to support 32-bit streams (bug #57939)
       int nbits = args(2).int_value ();
-      if (nbits != 8 || nbits != 16 || nbits != 24)
+      if (nbits != 8 && nbits != 16 && nbits != 24)
         error ("audioplayer: NBITS must be 8, 16, or 24");
 
       switch (args.length ())
