@@ -1,26 +1,27 @@
-/*
-
-Copyright (C) 2012-2018 Max Brister
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
-
-// Author: Max Brister <max@2bass.com>
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2012-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_jit_typeinfo_h)
 #define octave_jit_typeinfo_h 1
@@ -102,7 +103,7 @@ namespace octave
       return *m_array;
     }
 
-    int *m_ref_count;
+    int m_ref_count;
 
     U *m_slice_data;
     octave_idx_type m_slice_len;
@@ -222,7 +223,7 @@ namespace octave
     llvm::Type *m_packed_type[jit_convention::length];
   };
 
-  // seperate print function to allow easy printing if type is null
+  // separate print function to allow easy printing if type is null
   std::ostream& jit_print (std::ostream& os, jit_type *atype);
 
   // Find common type
@@ -255,7 +256,7 @@ namespace octave
 
     jit_function (const jit_function& fn);
 
-    // erase the interal LLVM function (if it exists).  Will become invalid.
+    // erase the internal LLVM function (if it exists).  Will become invalid.
     void erase (void);
 
     bool valid (void) const { return m_llvm_function; }
@@ -345,8 +346,8 @@ namespace octave
 
   std::ostream& operator << (std::ostream& os, const jit_function& fn);
 
-  // Keeps track of information about how to implement operations (+, -, *, ect)
-  // and their resulting types.
+  // Keeps track of information about how to implement operations (+, -,
+  // *, etc.) and their resulting types.
   class
   jit_operation
   {
@@ -429,7 +430,7 @@ namespace octave
     };
 
     typedef std::map<const signature_vec *, jit_function *, signature_cmp>
-    generated_map;
+      generated_map;
 
     mutable generated_map m_generated;
 
@@ -754,7 +755,7 @@ namespace octave
 
     const jit_operation& do_binary_op (int op) const
     {
-      assert (static_cast<size_t>(op) < m_binary_ops.size ());
+      assert (static_cast<size_t> (op) < m_binary_ops.size ());
       return m_binary_ops[op];
     }
 
