@@ -1,31 +1,33 @@
-// Template array classes
-/*
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1996-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
-Copyright (C) 1996-2015 John W. Eaton
-Copyright (C) 2008-2009 Jaroslav Hajek
-Copyright (C) 2010 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
-
-#if !defined (octave_DiagArray2_h)
+#if ! defined (octave_DiagArray2_h)
 #define octave_DiagArray2_h 1
 
+#include "octave-config.h"
+
 #include <cassert>
 #include <cstdlib>
 
@@ -34,7 +36,7 @@ along with Octave; see the file COPYING.  If not, see
 // Array<T> is inherited privately so that some methods, like index, don't
 // produce unexpected results.
 
-template <class T>
+template <typename T>
 class
 DiagArray2 : protected Array<T>
 {
@@ -62,11 +64,11 @@ public:
   DiagArray2 (const DiagArray2<T>& a)
     : Array<T> (a), d1 (a.d1), d2 (a.d2) { }
 
-  template <class U>
+  template <typename U>
   DiagArray2 (const DiagArray2<U>& a)
     : Array<T> (a.extract_diag ()), d1 (a.dim1 ()), d2 (a.dim2 ()) { }
 
-  ~DiagArray2 (void) { }
+  ~DiagArray2 (void) = default;
 
   DiagArray2<T>& operator = (const DiagArray2<T>& a)
   {
@@ -87,9 +89,9 @@ public:
   octave_idx_type cols (void) const { return dim2 (); }
   octave_idx_type columns (void) const { return dim2 (); }
 
-  octave_idx_type diag_length (void) const { return Array<T>::length (); }
+  octave_idx_type diag_length (void) const { return Array<T>::numel (); }
   // FIXME: a dangerous ambiguity?
-  octave_idx_type length (void) const { return Array<T>::length (); }
+  octave_idx_type length (void) const { return Array<T>::numel (); }
   octave_idx_type nelem (void) const { return dim1 () * dim2 (); }
   octave_idx_type numel (void) const { return nelem (); }
 
@@ -97,8 +99,12 @@ public:
 
   dim_vector dims (void) const { return dim_vector (d1, d2); }
 
-  Array<T> diag (octave_idx_type k = 0) const GCC_ATTR_DEPRECATED;
+  bool isempty (void) const { return numel () == 0; }
+
+  int ndims (void) const { return 2; }
+
   Array<T> extract_diag (octave_idx_type k = 0) const;
+
   DiagArray2<T> build_diag_matrix () const
   {
     return DiagArray2<T> (array_value ());
@@ -121,28 +127,18 @@ public:
   { return Array<T>::elem (i); }
 
   T checkelem (octave_idx_type r, octave_idx_type c) const
-  {
-    return check_idx (r, c) ? elem (r, c) : T (0);
-  }
+  { return check_idx (r, c) ? elem (r, c) : T (0); }
 
   T operator () (octave_idx_type r, octave_idx_type c) const
   {
-#if defined (BOUNDS_CHECKING)
-    return checkelem (r, c);
-#else
     return elem (r, c);
-#endif
   }
 
   T& checkelem (octave_idx_type r, octave_idx_type c);
 
   T& operator () (octave_idx_type r, octave_idx_type c)
   {
-#if defined (BOUNDS_CHECKING)
-    return checkelem (r, c);
-#else
     return elem (r, c);
-#endif
   }
 
   // No checking.
@@ -165,15 +161,15 @@ public:
   }
 
   DiagArray2<T> transpose (void) const;
-  DiagArray2<T> hermitian (T (*fcn) (const T&) = 0) const;
+  DiagArray2<T> hermitian (T (*fcn) (const T&) = nullptr) const;
 
   Array<T> array_value (void) const;
 
-  const T *data (void) const { return Array<T>::data (); }
+  const T * data (void) const { return Array<T>::data (); }
 
-  const T *fortran_vec (void) const { return Array<T>::fortran_vec (); }
+  const T * fortran_vec (void) const { return Array<T>::fortran_vec (); }
 
-  T *fortran_vec (void) { return Array<T>::fortran_vec (); }
+  T * fortran_vec (void) { return Array<T>::fortran_vec (); }
 
   void print_info (std::ostream& os, const std::string& prefix) const
   { Array<T>::print_info (os, prefix); }
