@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2008-2016 Jaroslav Hajek
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2008-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -49,12 +52,6 @@ PermMatrix::setup (const Array<octave_idx_type>& p, bool colp, bool check)
     *this = this->transpose ();
 }
 
-PermMatrix::PermMatrix (const Array<octave_idx_type>& p)
-  : Array<octave_idx_type> (p)
-{
-  setup (p, false, true);
-}
-
 PermMatrix::PermMatrix (const Array<octave_idx_type>& p, bool colp, bool check)
   : Array<octave_idx_type> (p)
 {
@@ -77,12 +74,6 @@ PermMatrix::setup (const idx_vector& idx, bool colp, octave_idx_type n)
     *this = this->transpose ();
 }
 
-PermMatrix::PermMatrix (const idx_vector& idx)
-  : Array<octave_idx_type> ()
-{
-  setup (idx, false, 0);
-}
-
 PermMatrix::PermMatrix (const idx_vector& idx, bool colp, octave_idx_type n)
   : Array<octave_idx_type> ()
 {
@@ -233,4 +224,3 @@ operator *(const PermMatrix& a, const PermMatrix& b)
 
   return r;
 }
-
