@@ -1,34 +1,36 @@
-/*
-
-Copyright (C) 1994-2018 John W. Eaton
-Copyright (C) 2008-2009 Jaroslav Hajek
-Copyright (C) 2009 VZLU Prague, a.s.
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1994-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
 #endif
 
 #include <algorithm>
-#include <iostream>
+#include <istream>
 #include <limits>
+#include <ostream>
 
 #include "Array-util.h"
 #include "DET.h"
@@ -45,7 +47,6 @@ along with Octave; see the file COPYING.  If not, see
 #include "fMatrix.h"
 #include "fNDArray.h"
 #include "fRowVector.h"
-#include "functor.h"
 #include "lo-blas-proto.h"
 #include "lo-error.h"
 #include "lo-ieee.h"
@@ -435,7 +436,7 @@ float
 norm1 (const FloatMatrix& a)
 {
   float anorm = 0.0;
-  FloatColumnVector colsum = a.abs ().sum ().row (0);
+  FloatRowVector colsum = a.abs ().sum ().row (0);
 
   for (octave_idx_type i = 0; i < colsum.numel (); i++)
     {
@@ -578,8 +579,6 @@ FloatMatrix::finverse (MatrixType& mattype, octave_idx_type& info, float& rcon,
   F77_XFCN (sgetri, SGETRI, (nc, tmp_data, nr, pipvt,
                              z.fortran_vec (), lwork, tmp_info));
 
-  info = tmp_info;
-
   lwork = static_cast<F77_INT> (z(0));
   lwork = (lwork < 4 * nc ? 4 * nc : lwork);
   z.resize (dim_vector (lwork, 1));
@@ -588,8 +587,8 @@ FloatMatrix::finverse (MatrixType& mattype, octave_idx_type& info, float& rcon,
   info = 0;
   tmp_info = 0;
 
-  // Calculate the norm of the matrix, for later use.
-  float anorm = 0;
+  // Calculate the norm of the matrix for later use when determining rcon.
+  float anorm;
   if (calc_cond)
     anorm = norm1 (retval);
 
@@ -669,8 +668,8 @@ FloatMatrix::inverse (MatrixType& mattype, octave_idx_type& info, float& rcon,
       if (! mattype.ishermitian ())
         ret = finverse (mattype, info, rcon, force, calc_cond);
 
-      if ((calc_cond || mattype.ishermitian ()) && rcon == 0.
-          && ! (numel () == 1))
+      if ((calc_cond || mattype.ishermitian ()) && rcon == 0.0
+          && (numel () != 1))
         ret = FloatMatrix (rows (), columns (),
                            octave::numeric_limits<float>::Inf ());
     }
@@ -805,232 +804,40 @@ FloatMatrix::ifourier2d (void) const
 
 #else
 
-#include "lo-fftpack-proto.h"
-
 FloatComplexMatrix
 FloatMatrix::fourier (void) const
 {
-  FloatComplexMatrix retval;
+  (*current_liboctave_error_handler)
+    ("support for FFTW was unavailable or disabled when liboctave was built");
 
-  octave_idx_type nr = rows ();
-  octave_idx_type nc = cols ();
-  octave_idx_type nsamples;
-
-  F77_INT npts;
-
-  if (nr == 1 || nc == 1)
-    {
-      npts = octave::to_f77_int (nr > nc ? nr : nc);
-      nsamples = 1;
-    }
-  else
-    {
-      npts = octave::to_f77_int (nr);
-      nsamples = nc;
-    }
-
-  octave_idx_type nn = 4*npts+15;
-
-  Array<FloatComplex> wsave (dim_vector (nn, 1));
-  FloatComplex *pwsave = wsave.fortran_vec ();
-
-  retval = FloatComplexMatrix (*this);
-  FloatComplex *tmp_data = retval.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (octave_idx_type j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      F77_FUNC (cfftf, CFFTF) (npts, F77_CMPLX_ARG (&tmp_data[npts*j]),
-                               F77_CMPLX_ARG (pwsave));
-    }
-
-  return retval;
+  return FloatComplexMatrix ();
 }
 
 FloatComplexMatrix
 FloatMatrix::ifourier (void) const
 {
-  FloatComplexMatrix retval;
+  (*current_liboctave_error_handler)
+    ("support for FFTW was unavailable or disabled when liboctave was built");
 
-  octave_idx_type nr = rows ();
-  octave_idx_type nc = cols ();
-  octave_idx_type nsamples;
-
-  F77_INT npts;
-
-  if (nr == 1 || nc == 1)
-    {
-      npts = octave::to_f77_int (nr > nc ? nr : nc);
-      nsamples = 1;
-    }
-  else
-    {
-      npts = F77_INT (nr);
-      nsamples = nc;
-    }
-
-  octave_idx_type nn = 4*npts+15;
-
-  Array<FloatComplex> wsave (dim_vector (nn, 1));
-  FloatComplex *pwsave = wsave.fortran_vec ();
-
-  retval = FloatComplexMatrix (*this);
-  FloatComplex *tmp_data = retval.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (octave_idx_type j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      F77_FUNC (cfftb, CFFTB) (npts, F77_CMPLX_ARG (&tmp_data[npts*j]),
-                               F77_CMPLX_ARG (pwsave));
-    }
-
-  for (octave_idx_type j = 0; j < npts*nsamples; j++)
-    tmp_data[j] = tmp_data[j] / static_cast<float> (npts);
-
-  return retval;
+  return FloatComplexMatrix ();
 }
 
 FloatComplexMatrix
 FloatMatrix::fourier2d (void) const
 {
-  FloatComplexMatrix retval;
+  (*current_liboctave_error_handler)
+    ("support for FFTW was unavailable or disabled when liboctave was built");
 
-  F77_INT nr = octave::to_f77_int (rows ());
-  F77_INT nc = octave::to_f77_int (cols ());
-
-  F77_INT npts, nsamples;
-
-  if (nr == 1 || nc == 1)
-    {
-      npts = (nr > nc ? nr : nc);
-      nsamples = 1;
-    }
-  else
-    {
-      npts = nr;
-      nsamples = nc;
-    }
-
-  F77_INT nn = 4*npts+15;
-
-  Array<FloatComplex> wsave (dim_vector (nn, 1));
-  FloatComplex *pwsave = wsave.fortran_vec ();
-
-  retval = FloatComplexMatrix (*this);
-  FloatComplex *tmp_data = retval.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (F77_INT j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      F77_FUNC (cfftf, CFFTF) (npts, F77_CMPLX_ARG (&tmp_data[npts*j]),
-                               F77_CMPLX_ARG (pwsave));
-    }
-
-  npts = nc;
-  nsamples = nr;
-  nn = 4*npts+15;
-
-  wsave.resize (dim_vector (nn, 1));
-  pwsave = wsave.fortran_vec ();
-
-  Array<FloatComplex> tmp (dim_vector (npts, 1));
-  FloatComplex *prow = tmp.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (F77_INT j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      for (F77_INT i = 0; i < npts; i++)
-        prow[i] = tmp_data[i*nr + j];
-
-      F77_FUNC (cfftf, CFFTF) (npts, F77_CMPLX_ARG (prow), F77_CMPLX_ARG (pwsave));
-
-      for (F77_INT i = 0; i < npts; i++)
-        tmp_data[i*nr + j] = prow[i];
-    }
-
-  return retval;
+  return FloatComplexMatrix ();
 }
 
 FloatComplexMatrix
 FloatMatrix::ifourier2d (void) const
 {
-  FloatComplexMatrix retval;
+  (*current_liboctave_error_handler)
+    ("support for FFTW was unavailable or disabled when liboctave was built");
 
-  F77_INT nr = octave::to_f77_int (rows ());
-  F77_INT nc = octave::to_f77_int (cols ());
-
-  F77_INT npts, nsamples;
-
-  if (nr == 1 || nc == 1)
-    {
-      npts = (nr > nc ? nr : nc);
-      nsamples = 1;
-    }
-  else
-    {
-      npts = nr;
-      nsamples = nc;
-    }
-
-  F77_INT nn = 4*npts+15;
-
-  Array<FloatComplex> wsave (dim_vector (nn, 1));
-  FloatComplex *pwsave = wsave.fortran_vec ();
-
-  retval = FloatComplexMatrix (*this);
-  FloatComplex *tmp_data = retval.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (F77_INT j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      F77_FUNC (cfftb, CFFTB) (npts, F77_CMPLX_ARG (&tmp_data[npts*j]),
-                               F77_CMPLX_ARG (pwsave));
-    }
-
-  for (F77_INT j = 0; j < npts*nsamples; j++)
-    tmp_data[j] = tmp_data[j] / static_cast<float> (npts);
-
-  npts = nc;
-  nsamples = nr;
-  nn = 4*npts+15;
-
-  wsave.resize (dim_vector (nn, 1));
-  pwsave = wsave.fortran_vec ();
-
-  Array<FloatComplex> tmp (dim_vector (npts, 1));
-  FloatComplex *prow = tmp.fortran_vec ();
-
-  F77_FUNC (cffti, CFFTI) (npts, F77_CMPLX_ARG (pwsave));
-
-  for (F77_INT j = 0; j < nsamples; j++)
-    {
-      octave_quit ();
-
-      for (F77_INT i = 0; i < npts; i++)
-        prow[i] = tmp_data[i*nr + j];
-
-      F77_FUNC (cfftb, CFFTB) (npts, F77_CMPLX_ARG (prow), F77_CMPLX_ARG (pwsave));
-
-      for (F77_INT i = 0; i < npts; i++)
-        tmp_data[i*nr + j] = prow[i] / static_cast<float> (npts);
-    }
-
-  return retval;
+  return FloatComplexMatrix ();
 }
 
 #endif
@@ -1095,7 +902,8 @@ FloatMatrix::determinant (MatrixType& mattype,
       FloatMatrix atmp = *this;
       float *tmp_data = atmp.fortran_vec ();
 
-      float anorm = 0;
+      // Calculate the norm of the matrix for later use when determining rcon.
+      float anorm;
       if (calc_cond)
         anorm = norm1 (*this);
 
@@ -1116,23 +924,26 @@ FloatMatrix::determinant (MatrixType& mattype,
         }
       else
         {
-          Array<float> z (dim_vector (3 * nc, 1));
-          float *pz = z.fortran_vec ();
-          Array<F77_INT> iz (dim_vector (nc, 1));
-          F77_INT *piz = iz.fortran_vec ();
+          if (calc_cond)
+            {
+              Array<float> z (dim_vector (3 * nc, 1));
+              float *pz = z.fortran_vec ();
+              Array<F77_INT> iz (dim_vector (nc, 1));
+              F77_INT *piz = iz.fortran_vec ();
 
-          F77_XFCN (spocon, SPOCON, (F77_CONST_CHAR_ARG2 (&job, 1),
-                                     nr, tmp_data, nr, anorm,
-                                     rcon, pz, piz, tmp_info
-                                     F77_CHAR_ARG_LEN (1)));
+              F77_XFCN (spocon, SPOCON, (F77_CONST_CHAR_ARG2 (&job, 1),
+                                         nr, tmp_data, nr, anorm,
+                                         rcon, pz, piz, tmp_info
+                                         F77_CHAR_ARG_LEN (1)));
 
-          info = tmp_info;
+              info = tmp_info;
 
-          if (info != 0)
-            rcon = 0.0;
+              if (info != 0)
+                rcon = 0.0;
+            }
 
           for (F77_INT i = 0; i < nc; i++)
-            retval *= atmp (i,i);
+            retval *= atmp(i,i);
 
           retval = retval.square ();
         }
@@ -1151,8 +962,8 @@ FloatMatrix::determinant (MatrixType& mattype,
       info = 0;
       F77_INT tmp_info = 0;
 
-      // Calculate the norm of the matrix, for later use.
-      float anorm = 0;
+      // Calculate the norm of the matrix for later use when determining rcon.
+      float anorm;
       if (calc_cond)
         anorm = norm1 (*this);
 
@@ -1339,7 +1150,7 @@ FloatMatrix::rcond (MatrixType& mattype) const
               Array<F77_INT> ipvt (dim_vector (nr, 1));
               F77_INT *pipvt = ipvt.fortran_vec ();
 
-              if (anorm < 0.)
+              if (anorm < 0.0)
                 anorm = norm1 (atmp);
 
               Array<float> z (dim_vector (4 * nc, 1));
@@ -1400,7 +1211,7 @@ FloatMatrix::utsolve (MatrixType& mattype, const FloatMatrix& b,
 
       if (typ == MatrixType::Permuted_Upper || typ == MatrixType::Upper)
         {
-          rcon = 1.;
+          rcon = 1.0;
           info = 0;
 
           if (typ == MatrixType::Permuted_Upper)
@@ -1503,7 +1314,7 @@ FloatMatrix::ltsolve (MatrixType& mattype, const FloatMatrix& b,
 
       if (typ == MatrixType::Permuted_Lower || typ == MatrixType::Lower)
         {
-          rcon = 1.;
+          rcon = 1.0;
           info = 0;
 
           if (typ == MatrixType::Permuted_Lower)
@@ -1603,8 +1414,8 @@ FloatMatrix::fsolve (MatrixType& mattype, const FloatMatrix& b,
     {
       volatile int typ = mattype.type ();
 
-      // Calculate the norm of the matrix, for later use.
-      float anorm = -1.;
+      // Calculate the norm of the matrix for later use when determining rcon.
+      float anorm = -1.0;
 
       if (typ == MatrixType::Hermitian)
         {
@@ -1614,7 +1425,9 @@ FloatMatrix::fsolve (MatrixType& mattype, const FloatMatrix& b,
           FloatMatrix atmp = *this;
           float *tmp_data = atmp.fortran_vec ();
 
-          anorm = norm1 (atmp);
+          // The norm of the matrix for later use when determining rcon.
+          if (calc_cond)
+            anorm = norm1 (atmp);
 
           F77_INT tmp_info = 0;
 
@@ -1695,7 +1508,7 @@ FloatMatrix::fsolve (MatrixType& mattype, const FloatMatrix& b,
           FloatMatrix atmp = *this;
           float *tmp_data = atmp.fortran_vec ();
 
-          if (anorm < 0.0)
+          if (calc_cond && anorm < 0.0)
             anorm = norm1 (atmp);
 
           Array<float> z (dim_vector (4 * nc, 1));
@@ -1726,8 +1539,7 @@ FloatMatrix::fsolve (MatrixType& mattype, const FloatMatrix& b,
             {
               if (calc_cond)
                 {
-                  // Now calculate the condition number for
-                  // non-singular matrix.
+                  // Calculate the condition number for non-singular matrix.
                   char job = '1';
                   F77_XFCN (sgecon, SGECON, (F77_CONST_CHAR_ARG2 (&job, 1),
                                              nc, tmp_data, nr, anorm,
@@ -2127,13 +1939,12 @@ FloatMatrix::lssolve (const FloatMatrix& b, octave_idx_type& info,
 {
   FloatMatrix retval;
 
-  F77_INT nrhs = octave::to_f77_int (b.cols ());
-
   F77_INT m = octave::to_f77_int (rows ());
   F77_INT n = octave::to_f77_int (cols ());
 
   F77_INT b_nr = octave::to_f77_int (b.rows ());
   F77_INT b_nc = octave::to_f77_int (b.cols ());
+  F77_INT nrhs = b_nc;  // alias for code readability
 
   if (m != b_nr)
     (*current_liboctave_error_handler)
@@ -2188,7 +1999,6 @@ FloatMatrix::lssolve (const FloatMatrix& b, octave_idx_type& info,
       float dminmn = static_cast<float> (minmn);
       float dsmlsizp1 = static_cast<float> (smlsiz+1);
       float tmp = octave::math::log2 (dminmn / dsmlsizp1);
-      float anorm = 0.0;
 
       F77_INT nlvl = static_cast<F77_INT> (tmp) + 1;
       if (nlvl < 0)
@@ -2250,12 +2060,11 @@ FloatMatrix::lssolve (const FloatMatrix& b, octave_idx_type& info,
       lwork = static_cast<F77_INT> (work(0));
       work.resize (dim_vector (lwork, 1));
 
-      anorm = norm1 (*this);
+      float anorm = norm1 (*this);
 
       if (octave::math::isinf (anorm))
         {
           rcon = 0.0;
-          octave::warn_singular_matrix ();
           retval = FloatMatrix (n, b_nc, 0.0);
         }
       else if (octave::math::isnan (anorm))
@@ -3200,7 +3009,7 @@ FloatMatrix linspace (const FloatColumnVector& x1,
     (*current_liboctave_error_handler)
       ("linspace: vectors must be of equal length");
 
-  NoAlias<FloatMatrix> retval;
+  FloatMatrix retval;
 
   if (n < 1)
     {
@@ -3210,19 +3019,19 @@ FloatMatrix linspace (const FloatColumnVector& x1,
 
   retval.clear (m, n);
   for (octave_idx_type i = 0; i < m; i++)
-    retval(i, 0) = x1(i);
+    retval.xelem (i, 0) = x1(i);
 
   // The last column is unused so temporarily store delta there
-  float *delta = &retval(0, n-1);
+  float *delta = &retval.xelem (0, n-1);
   for (octave_idx_type i = 0; i < m; i++)
-    delta[i] = (x2(i) - x1(i)) / (n - 1);
+    delta[i] = (x1(i) == x2(i)) ? 0 : (x2(i) - x1(i)) / (n - 1);
 
   for (octave_idx_type j = 1; j < n-1; j++)
     for (octave_idx_type i = 0; i < m; i++)
-      retval(i, j) = x1(i) + j*delta[i];
+      retval.xelem (i, j) = x1(i) + j*delta[i];
 
   for (octave_idx_type i = 0; i < m; i++)
-    retval(i, n-1) = x2(i);
+    retval.xelem (i, n-1) = x2(i);
 
   return retval;
 }
