@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1993-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1993-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_ODEFunc_h)
 #define octave_ODEFunc_h 1
@@ -37,10 +40,10 @@ public:
   typedef Matrix (*ODEJacFunc) (const ColumnVector&, double);
 
   ODEFunc (void)
-    : fun (0), jac (0), reset (true) { }
+    : fun (nullptr), jac (nullptr), reset (true) { }
 
   ODEFunc (ODERHSFunc f)
-    : fun (f), jac (0), reset (true) { }
+    : fun (f), jac (nullptr), reset (true) { }
 
   ODEFunc (ODERHSFunc f, ODEJacFunc j)
     : fun (f), jac (j), reset (true) { }
@@ -59,7 +62,7 @@ public:
     return *this;
   }
 
-  virtual ~ODEFunc (void) { }
+  virtual ~ODEFunc (void) = default;
 
   ODERHSFunc function (void) const { return fun; }
 
