@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 1994-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1994-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_fEIG_h)
 #define octave_fEIG_h 1
@@ -27,9 +30,10 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <iosfwd>
 
-#include "fMatrix.h"
-#include "fCMatrix.h"
 #include "fCColVector.h"
+#include "fCMatrix.h"
+
+class FloatMatrix;
 
 class
 OCTAVE_API
@@ -112,7 +116,7 @@ public:
     return *this;
   }
 
-  ~FloatEIG (void) { }
+  ~FloatEIG (void) = default;
 
   FloatComplexColumnVector eigenvalues (void) const { return lambda; }
   FloatComplexMatrix right_eigenvectors (void) const { return v; }
