@@ -1,105 +1,104 @@
-/*
-
-Copyright (C) 1993-2017 John W. Eaton
-Copyright (C) 2009 Jaroslav Hajek
-Copyright (C) 2009 VZLU Prague
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 1993-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if ! defined (octave_mx_inlines_h)
 #define octave_mx_inlines_h 1
 
-// This file should not include config.h.  It is only included in other
-// C++ source files that should have included config.h before including
-// this file.
+// This file should *not* include config.h.  It is only included in other C++
+// source files that should have included config.h before including this file.
 
 #include <cstddef>
 #include <cmath>
-#include <cstring>
-#include <memory>
 
-#include "quit.h"
+#include <algorithm>
 
-#include "oct-cmplx.h"
-#include "oct-locbuf.h"
-#include "oct-inttypes.h"
-#include "Array.h"
 #include "Array-util.h"
-
+#include "Array.h"
 #include "bsxfun.h"
+#include "oct-cmplx.h"
+#include "oct-inttypes.h"
+#include "oct-locbuf.h"
 
 // Provides some commonly repeated, basic loop templates.
 
 template <typename R, typename S>
-inline void mx_inline_fill (size_t n, R *r, S s) throw ()
+inline void mx_inline_fill (size_t n, R *r, S s)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = s;
 }
 
-#define DEFMXUNOP(F, OP)                                \
-  template <typename R, typename X>                     \
-  inline void F (size_t n, R *r, const X *x) throw ()   \
-  {                                                     \
-    for (size_t i = 0; i < n; i++)                      \
-      r[i] = OP x[i];                                   \
-  }
+template <typename R, typename X>
+inline void
+mx_inline_uminus (size_t n, R *r, const X *x)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = -x[i];
+}
 
-DEFMXUNOP (mx_inline_uminus, -)
+template <typename R>
+inline void
+mx_inline_uminus2 (size_t n, R *r)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = -r[i];
+}
 
-#define DEFMXUNOPEQ(F, OP)                      \
-  template <typename R>                         \
-  inline void F (size_t n, R *r) throw ()       \
-  {                                             \
-    for (size_t i = 0; i < n; i++)              \
-      r[i] = OP r[i];                           \
-  }
+template <typename X>
+inline void
+mx_inline_iszero (size_t n, bool *r, const X *x)
+{
+  const X zero = X ();
+  for (size_t i = 0; i < n; i++)
+    r[i] = x[i] == zero;
+}
 
-DEFMXUNOPEQ (mx_inline_uminus2, -)
-
-#define DEFMXUNBOOLOP(F, OP)                                    \
-  template <typename X>                                         \
-  inline void F (size_t n, bool *r, const X *x) throw ()        \
-  {                                                             \
-    const X zero = X ();                                        \
-    for (size_t i = 0; i < n; i++)                              \
-      r[i] = x[i] OP zero;                                      \
-  }
-
-DEFMXUNBOOLOP (mx_inline_iszero, ==)
-DEFMXUNBOOLOP (mx_inline_notzero, !=)
+template <typename X>
+inline void
+mx_inline_notzero (size_t n, bool *r, const X *x)
+{
+  const X zero = X ();
+  for (size_t i = 0; i < n; i++)
+    r[i] = x[i] != zero;
+}
 
 #define DEFMXBINOP(F, OP)                                               \
   template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, const X *x, const Y *y) throw ()       \
+  inline void F (size_t n, R *r, const X *x, const Y *y)        \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x[i] OP y[i];                                              \
   }                                                                     \
   template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, const X *x, Y y) throw ()              \
+  inline void F (size_t n, R *r, const X *x, Y y)               \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x[i] OP y;                                                 \
   }                                                                     \
   template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, X x, const Y *y) throw ()              \
+  inline void F (size_t n, R *r, X x, const Y *y)               \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x OP y[i];                                                 \
@@ -112,13 +111,13 @@ DEFMXBINOP (mx_inline_div, /)
 
 #define DEFMXBINOPEQ(F, OP)                             \
   template <typename R, typename X>                     \
-  inline void F (size_t n, R *r, const X *x) throw ()   \
+  inline void F (size_t n, R *r, const X *x)    \
   {                                                     \
     for (size_t i = 0; i < n; i++)                      \
       r[i] OP x[i];                                     \
   }                                                     \
   template <typename R, typename X>                     \
-  inline void F (size_t n, R *r, X x) throw ()          \
+  inline void F (size_t n, R *r, X x)           \
   {                                                     \
     for (size_t i = 0; i < n; i++)                      \
       r[i] OP x;                                        \
@@ -131,19 +130,19 @@ DEFMXBINOPEQ (mx_inline_div2, /=)
 
 #define DEFMXCMPOP(F, OP)                                               \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, const X *x, const Y *y) throw ()    \
+  inline void F (size_t n, bool *r, const X *x, const Y *y)     \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x[i] OP y[i];                                              \
   }                                                                     \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, const X *x, Y y) throw ()           \
+  inline void F (size_t n, bool *r, const X *x, Y y)            \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x[i] OP y;                                                 \
   }                                                                     \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, X x, const Y *y) throw ()           \
+  inline void F (size_t n, bool *r, X x, const Y *y)            \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = x OP y[i];                                                 \
@@ -179,13 +178,13 @@ logical_value (const octave_int<T>& x)
 }
 
 template <typename X>
-void mx_inline_not (size_t n, bool *r, const X* x) throw ()
+void mx_inline_not (size_t n, bool *r, const X *x)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = ! logical_value (x[i]);
 }
 
-inline void mx_inline_not2 (size_t n, bool *r) throw ()
+inline void mx_inline_not2 (size_t n, bool *r)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = ! r[i];
@@ -193,21 +192,21 @@ inline void mx_inline_not2 (size_t n, bool *r) throw ()
 
 #define DEFMXBOOLOP(F, NOT1, OP, NOT2)                                  \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, const X *x, const Y *y) throw ()    \
+  inline void F (size_t n, bool *r, const X *x, const Y *y)     \
   {                                                                     \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = ((NOT1 logical_value (x[i]))                               \
               OP (NOT2 logical_value (y[i])));                          \
   }                                                                     \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, const X *x, Y y) throw ()           \
+  inline void F (size_t n, bool *r, const X *x, Y y)            \
   {                                                                     \
     const bool yy = (NOT2 logical_value (y));                           \
     for (size_t i = 0; i < n; i++)                                      \
       r[i] = (NOT1 logical_value (x[i])) OP yy;                         \
   }                                                                     \
   template <typename X, typename Y>                                     \
-  inline void F (size_t n, bool *r, X x, const Y *y) throw ()           \
+  inline void F (size_t n, bool *r, X x, const Y *y)            \
   {                                                                     \
     const bool xx = (NOT1 logical_value (x));                           \
     for (size_t i = 0; i < n; i++)                                      \
@@ -221,26 +220,41 @@ DEFMXBOOLOP (mx_inline_not_or, !, |, )
 DEFMXBOOLOP (mx_inline_and_not, , &, !)
 DEFMXBOOLOP (mx_inline_or_not, , |, !)
 
-#define DEFMXBOOLOPEQ(F, OP)                                    \
-  template <typename X>                                         \
-  inline void F (size_t n, bool *r, const X *x) throw ()        \
-  {                                                             \
-    for (size_t i = 0; i < n; i++)                              \
-      r[i] OP logical_value (x[i]);                             \
-  }                                                             \
-  template <typename X>                                         \
-  inline void F (size_t n, bool *r, X x) throw ()               \
-  {                                                             \
-    for (size_t i = 0; i < n; i++)                              \
-      r[i] OP x;                                                \
-  }
+template <typename X>
+inline void
+mx_inline_and2 (size_t n, bool *r, const X *x)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] &= logical_value (x[i]);
+}
 
-DEFMXBOOLOPEQ (mx_inline_and2, &=)
-DEFMXBOOLOPEQ (mx_inline_or2, |=)
+template <typename X>
+inline void
+mx_inline_and2 (size_t n, bool *r, X x)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] &= x;
+}
+
+template <typename X>
+inline void
+mx_inline_or2 (size_t n, bool *r, const X *x)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] |= logical_value (x[i]);
+}
+
+template <typename X>
+inline void
+mx_inline_or2 (size_t n, bool *r, X x)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] |= x;
+}
 
 template <typename T>
 inline bool
-mx_inline_any_nan (size_t n, const T* x)  throw ()
+mx_inline_any_nan (size_t n, const T *x)
 {
   for (size_t i = 0; i < n; i++)
     {
@@ -253,11 +267,11 @@ mx_inline_any_nan (size_t n, const T* x)  throw ()
 
 template <typename T>
 inline bool
-mx_inline_all_finite (size_t n, const T* x)  throw ()
+mx_inline_all_finite (size_t n, const T *x)
 {
   for (size_t i = 0; i < n; i++)
     {
-      if (! octave::math::finite (x[i]))
+      if (! octave::math::isfinite (x[i]))
         return false;
     }
 
@@ -266,7 +280,7 @@ mx_inline_all_finite (size_t n, const T* x)  throw ()
 
 template <typename T>
 inline bool
-mx_inline_any_negative (size_t n, const T* x) throw ()
+mx_inline_any_negative (size_t n, const T *x)
 {
   for (size_t i = 0; i < n; i++)
     {
@@ -279,7 +293,7 @@ mx_inline_any_negative (size_t n, const T* x) throw ()
 
 template <typename T>
 inline bool
-mx_inline_any_positive (size_t n, const T* x) throw ()
+mx_inline_any_positive (size_t n, const T *x)
 {
   for (size_t i = 0; i < n; i++)
     {
@@ -292,7 +306,7 @@ mx_inline_any_positive (size_t n, const T* x) throw ()
 
 template <typename T>
 inline bool
-mx_inline_all_real (size_t n, const std::complex<T>* x) throw ()
+mx_inline_all_real (size_t n, const std::complex<T>* x)
 {
   for (size_t i = 0; i < n; i++)
     {
@@ -303,71 +317,87 @@ mx_inline_all_real (size_t n, const std::complex<T>* x) throw ()
   return true;
 }
 
-#define DEFMXMAPPER(F, FUN)                             \
-  template <typename T>                                 \
-  inline void F (size_t n, T *r, const T *x) throw ()   \
-  {                                                     \
-    for (size_t i = 0; i < n; i++)                      \
-      r[i] = FUN (x[i]);                                \
-  }
-
 template <typename T>
-inline void mx_inline_real (size_t n, T *r, const std::complex<T>* x) throw ()
+inline void mx_inline_real (size_t n, T *r, const std::complex<T>* x)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = x[i].real ();
 }
 
 template <typename T>
-inline void mx_inline_imag (size_t n, T *r, const std::complex<T>* x) throw ()
+inline void mx_inline_imag (size_t n, T *r, const std::complex<T>* x)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = x[i].imag ();
 }
 
-// Pairwise minimums/maximums
-#define DEFMXMAPPER2(F, FUN)                                            \
-  template <typename T>                                                 \
-  inline void F (size_t n, T *r, const T *x, const T *y) throw ()       \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x[i], y[i]);                                          \
-  }                                                                     \
-  template <typename T>                                                 \
-  inline void F (size_t n, T *r, const T *x, T y) throw ()              \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x[i], y);                                             \
-  }                                                                     \
-  template <typename T>                                                 \
-  inline void F (size_t n, T *r, T x, const T *y) throw ()              \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x, y[i]);                                             \
-  }
+template <typename T>
+inline void
+mx_inline_xmin (size_t n, T *r, const T *x, const T *y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::min (x[i], y[i]);
+}
 
-DEFMXMAPPER2 (mx_inline_xmin, octave::math::min)
-DEFMXMAPPER2 (mx_inline_xmax, octave::math::max)
+template <typename T>
+inline void
+mx_inline_xmin (size_t n, T *r, const T *x, T y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::min (x[i], y);
+}
+
+template <typename T>
+inline void
+mx_inline_xmin (size_t n, T *r, T x, const T *y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::min (x, y[i]);
+}
+
+template <typename T>
+inline void
+mx_inline_xmax (size_t n, T *r, const T *x, const T *y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::max (x[i], y[i]);
+}
+
+template <typename T>
+inline void
+mx_inline_xmax (size_t n, T *r, const T *x, T y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::max (x[i], y);
+}
+
+template <typename T>
+inline void
+mx_inline_xmax (size_t n, T *r, T x, const T *y)
+{
+  for (size_t i = 0; i < n; i++)
+    r[i] = octave::math::max (x, y[i]);
+}
 
 // Specialize array-scalar max/min
 #define DEFMINMAXSPEC(T, F, OP)                                 \
   template <>                                                   \
-  inline void F<T> (size_t n, T *r, const T *x, T y) throw ()   \
+  inline void F<T> (size_t n, T *r, const T *x, T y)    \
   {                                                             \
     if (octave::math::isnan (y))                                \
       std::memcpy (r, x, n * sizeof (T));                       \
     else                                                        \
       for (size_t i = 0; i < n; i++)                            \
-        r[i] = (x[i] OP y) ? x[i] : y;                          \
+        r[i] = (x[i] OP y ? x[i] : y);                          \
   }                                                             \
   template <>                                                   \
-  inline void F<T> (size_t n, T *r, T x, const T *y) throw ()   \
+  inline void F<T> (size_t n, T *r, T x, const T *y)    \
   {                                                             \
     if (octave::math::isnan (x))                                \
       std::memcpy (r, y, n * sizeof (T));                       \
     else                                                        \
       for (size_t i = 0; i < n; i++)                            \
-        r[i] = (y[i] OP x) ? y[i] : x;                          \
+        r[i] = (y[i] OP x ? y[i] : x);                          \
   }
 
 DEFMINMAXSPEC (double, mx_inline_xmin, <=)
@@ -375,43 +405,51 @@ DEFMINMAXSPEC (double, mx_inline_xmax, >=)
 DEFMINMAXSPEC (float, mx_inline_xmin, <=)
 DEFMINMAXSPEC (float, mx_inline_xmax, >=)
 
-// Pairwise power
-#define DEFMXMAPPER2X(F, FUN)                                           \
-  template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, const X *x, const Y *y) throw ()       \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x[i], y[i]);                                          \
-  }                                                                     \
-  template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, const X *x, Y y) throw ()              \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x[i], y);                                             \
-  }                                                                     \
-  template <typename R, typename X, typename Y>                         \
-  inline void F (size_t n, R *r, X x, const Y *y) throw ()              \
-  {                                                                     \
-    for (size_t i = 0; i < n; i++)                                      \
-      r[i] = FUN (x, y[i]);                                             \
-  }
-
+// FIXME: Is this comment correct anymore?  It seems like std::pow is chosen.
 // Let the compiler decide which pow to use, whichever best matches the
 // arguments provided.
-using std::pow;
-DEFMXMAPPER2X (mx_inline_pow, pow)
+
+template <typename R, typename X, typename Y>
+inline void
+mx_inline_pow (size_t n, R *r, const X *x, const Y *y)
+{
+  using std::pow;
+
+  for (size_t i = 0; i < n; i++)
+    r[i] = pow (x[i], y[i]);
+}
+
+template <typename R, typename X, typename Y>
+inline void
+mx_inline_pow (size_t n, R *r, const X *x, Y y)
+{
+  using std::pow;
+
+  for (size_t i = 0; i < n; i++)
+    r[i] = pow (x[i], y);
+}
+
+template <typename R, typename X, typename Y>
+inline void
+mx_inline_pow (size_t n, R *r, X x, const Y *y)
+{
+  using std::pow;
+
+  for (size_t i = 0; i < n; i++)
+    r[i] = pow (x, y[i]);
+}
 
 // Arbitrary function appliers.
 // The function is a template parameter to enable inlining.
 template <typename R, typename X, R fun (X x)>
-inline void mx_inline_map (size_t n, R *r, const X *x) throw ()
+inline void mx_inline_map (size_t n, R *r, const X *x)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = fun (x[i]);
 }
 
 template <typename R, typename X, R fun (const X& x)>
-inline void mx_inline_map (size_t n, R *r, const X *x) throw ()
+inline void mx_inline_map (size_t n, R *r, const X *x)
 {
   for (size_t i = 0; i < n; i++)
     r[i] = fun (x[i]);
@@ -423,7 +461,7 @@ inline void mx_inline_map (size_t n, R *r, const X *x) throw ()
 template <typename R, typename X>
 inline Array<R>
 do_mx_unary_op (const Array<X>& x,
-                void (*op) (size_t, R *, const X *) throw ())
+                void (*op) (size_t, R *, const X *))
 {
   Array<R> r (x.dims ());
   op (r.numel (), r.fortran_vec (), x.data ());
@@ -449,7 +487,7 @@ do_mx_unary_map (const Array<X>& x)
 template <typename R>
 inline Array<R>&
 do_mx_inplace_op (Array<R>& r,
-                  void (*op) (size_t, R *) throw ())
+                  void (*op) (size_t, R *))
 {
   op (r.numel (), r.fortran_vec ());
   return r;
@@ -458,9 +496,9 @@ do_mx_inplace_op (Array<R>& r,
 template <typename R, typename X, typename Y>
 inline Array<R>
 do_mm_binary_op (const Array<X>& x, const Array<Y>& y,
-                 void (*op) (size_t, R *, const X *, const Y *) throw (),
-                 void (*op1) (size_t, R *, X, const Y *) throw (),
-                 void (*op2) (size_t, R *, const X *, Y) throw (),
+                 void (*op) (size_t, R *, const X *, const Y *),
+                 void (*op1) (size_t, R *, X, const Y *),
+                 void (*op2) (size_t, R *, const X *, Y),
                  const char *opname)
 {
   dim_vector dx = x.dims ();
@@ -482,7 +520,7 @@ do_mm_binary_op (const Array<X>& x, const Array<Y>& y,
 template <typename R, typename X, typename Y>
 inline Array<R>
 do_ms_binary_op (const Array<X>& x, const Y& y,
-                 void (*op) (size_t, R *, const X *, Y) throw ())
+                 void (*op) (size_t, R *, const X *, Y))
 {
   Array<R> r (x.dims ());
   op (r.numel (), r.fortran_vec (), x.data (), y);
@@ -492,7 +530,7 @@ do_ms_binary_op (const Array<X>& x, const Y& y,
 template <typename R, typename X, typename Y>
 inline Array<R>
 do_sm_binary_op (const X& x, const Array<Y>& y,
-                 void (*op) (size_t, R *, X, const Y *) throw ())
+                 void (*op) (size_t, R *, X, const Y *))
 {
   Array<R> r (y.dims ());
   op (r.numel (), r.fortran_vec (), x, y.data ());
@@ -502,8 +540,8 @@ do_sm_binary_op (const X& x, const Array<Y>& y,
 template <typename R, typename X>
 inline Array<R>&
 do_mm_inplace_op (Array<R>& r, const Array<X>& x,
-                  void (*op) (size_t, R *, const X *) throw (),
-                  void (*op1) (size_t, R *, X) throw (),
+                  void (*op) (size_t, R *, const X *),
+                  void (*op1) (size_t, R *, X),
                   const char *opname)
 {
   dim_vector dr = r.dims ();
@@ -521,7 +559,7 @@ do_mm_inplace_op (Array<R>& r, const Array<X>& x,
 template <typename R, typename X>
 inline Array<R>&
 do_ms_inplace_op (Array<R>& r, const X& x,
-                  void (*op) (size_t, R *, X) throw ())
+                  void (*op) (size_t, R *, X))
 {
   op (r.numel (), r.fortran_vec (), x);
   return r;
@@ -529,7 +567,7 @@ do_ms_inplace_op (Array<R>& r, const X& x,
 
 template <typename T1, typename T2>
 inline bool
-mx_inline_equal (size_t n, const T1 *x, const T2 *y) throw ()
+mx_inline_equal (size_t n, const T1 *x, const T2 *y)
 {
   for (size_t i = 0; i < n; i++)
     if (x[i] != y[i])
@@ -540,7 +578,7 @@ mx_inline_equal (size_t n, const T1 *x, const T2 *y) throw ()
 template <typename T>
 inline bool
 do_mx_check (const Array<T>& a,
-             bool (*op) (size_t, const T *) throw ())
+             bool (*op) (size_t, const T *))
 {
   return op (a.numel (), a.data ());
 }
@@ -635,7 +673,7 @@ xis_false (const FloatComplex& x)
 
 #define OP_RED_SUM(ac, el) ac += el
 #define OP_RED_PROD(ac, el) ac *= el
-#define OP_RED_SUMSQ(ac, el) ac += el*el
+#define OP_RED_SUMSQ(ac, el) ac += ((el)*(el))
 #define OP_RED_SUMSQC(ac, el) ac += cabsq (el)
 
 inline void
@@ -700,7 +738,7 @@ op_dble_sum (double& ac, const octave_int<T>& el)
 #define OP_RED_FCN(F, TSRC, TRES, OP, ZERO)     \
   template <typename T>                         \
   inline TRES                                   \
-  F (const TSRC* v, octave_idx_type n)          \
+  F (const TSRC *v, octave_idx_type n)          \
   {                                             \
     TRES ac = ZERO;                             \
     for (octave_idx_type i = 0; i < n; i++)     \
@@ -724,7 +762,7 @@ OP_RED_FCN (mx_inline_all, T, bool, OP_RED_ALLC, true)
 #define OP_RED_FCN2(F, TSRC, TRES, OP, ZERO)                            \
   template <typename T>                                                 \
   inline void                                                           \
-  F (const TSRC* v, TRES *r, octave_idx_type m, octave_idx_type n)      \
+  F (const TSRC *v, TRES *r, octave_idx_type m, octave_idx_type n)      \
   {                                                                     \
     for (octave_idx_type i = 0; i < m; i++)                             \
       r[i] = ZERO;                                                      \
@@ -758,7 +796,7 @@ OP_RED_FCN2 (mx_inline_all_r, T, bool, OP_RED_ALLR, true)
 #define OP_ROW_SHORT_CIRCUIT(F, PRED, ZERO)                             \
   template <typename T>                                                 \
   inline void                                                           \
-  F (const T* v, bool *r, octave_idx_type m, octave_idx_type n)         \
+  F (const T *v, bool *r, octave_idx_type m, octave_idx_type n)         \
   {                                                                     \
     if (n <= 8)                                                         \
       return F ## _r (v, r, m, n);                                      \
