@@ -83,9 +83,8 @@ namespace octave
 
     size_t sz = fs.size ();
 
-    std::string ascii_fname = sys::get_ASCII_filename (fname);
-
-    std::ifstream file (ascii_fname.c_str (), std::ios::in | std::ios::binary);
+    std::ifstream file = sys::ifstream (fname.c_str (),
+                                        std::ios::in | std::ios::binary);
 
     if (file)
       {
