@@ -1,26 +1,27 @@
-/*
-
-Copyright (C) 2005-2019 David Bateman
-Copyright (C) 2002-2005 Paul Kienzle
-Copyright (C) 2012 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2002-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -44,26 +45,27 @@ along with Octave; see the file COPYING.  If not, see
 #include "quit.h"
 #include "lo-regexp.h"
 #include "str-vec.h"
-
-// Define the maximum number of retries for a pattern
-// that possibly results in an infinite recursion.
-#define PCRE_MATCHLIMIT_MAX 10
-
-// FIXME: should this be configurable?
-#define MAXLOOKBEHIND 10
-
-static bool lookbehind_warned = false;
-
-// FIXME: don't bother collecting and composing return values
-//        the user doesn't want.
+#include "unistr-wrappers.h"
 
 namespace octave
 {
+  // Define the maximum number of retries for a pattern
+  // that possibly results in an infinite recursion.
+#define PCRE_MATCHLIMIT_MAX 10
+
+  // FIXME: should this be configurable?
+#define MAXLOOKBEHIND 10
+
+  static bool lookbehind_warned = false;
+
+  // FIXME: don't bother collecting and composing return values
+  //        the user doesn't want.
+
   void
   regexp::free (void)
   {
-    if (data)
-      pcre_free (static_cast<pcre *> (data));
+    if (m_data)
+      pcre_free (static_cast<pcre *> (m_data));
   }
 
   void
@@ -79,11 +81,11 @@ namespace octave
     int inames = 0;
     std::ostringstream buf;
 
-    while ((new_pos = pattern.find ("(?", pos)) != std::string::npos)
+    while ((new_pos = m_pattern.find ("(?", pos)) != std::string::npos)
       {
-        if (pattern.at (new_pos + 2) == '<'
-            && !(pattern.at (new_pos + 3) == '='
-                 || pattern.at (new_pos + 3) == '!'))
+        if (m_pattern.at (new_pos + 2) == '<'
+            && !(m_pattern.at (new_pos + 3) == '='
+                 || m_pattern.at (new_pos + 3) == '!'))
           {
             // The syntax of named tokens in pcre is "(?P<name>...)" while
             // we need a syntax "(?<name>...)", so fix that here.  Also an
@@ -94,23 +96,23 @@ namespace octave
             // that here by replacing name tokens by dummy names, and dealing
             // with the dummy names later.
 
-            size_t tmp_pos = pattern.find_first_of ('>', new_pos);
+            size_t tmp_pos = m_pattern.find_first_of ('>', new_pos);
 
             if (tmp_pos == std::string::npos)
               (*current_liboctave_error_handler)
                 ("regexp: syntax error in pattern");
 
-            std::string tmp_name =
-              pattern.substr (new_pos+3, tmp_pos-new_pos-3);
+            std::string tmp_name
+              = m_pattern.substr (new_pos+3, tmp_pos-new_pos-3);
 
             bool found = false;
 
-            for (int i = 0; i < nnames; i++)
+            for (int i = 0; i < m_names; i++)
               {
-                if (named_pats(i) == tmp_name)
+                if (m_named_pats(i) == tmp_name)
                   {
-                    named_idx.resize (dim_vector (inames+1, 1));
-                    named_idx(inames) = i;
+                    m_named_idx.resize (dim_vector (inames+1, 1));
+                    m_named_idx(inames) = i;
                     found = true;
                     break;
                   }
@@ -118,14 +120,14 @@ namespace octave
 
             if (! found)
               {
-                named_idx.resize (dim_vector (inames+1, 1));
-                named_idx(inames) = nnames;
-                named_pats.append (tmp_name);
-                nnames++;
+                m_named_idx.resize (dim_vector (inames+1, 1));
+                m_named_idx(inames) = m_names;
+                m_named_pats.append (tmp_name);
+                m_names++;
               }
 
             if (new_pos - pos > 0)
-              buf << pattern.substr (pos, new_pos-pos);
+              buf << m_pattern.substr (pos, new_pos-pos);
             if (inames < 10)
               buf << "(?P<n00" << inames++;
             else if (inames < 100)
@@ -135,7 +137,7 @@ namespace octave
 
             pos = tmp_pos;
           }
-        else if (pattern.at (new_pos + 2) == '<')
+        else if (m_pattern.at (new_pos + 2) == '<')
           {
             // Find lookbehind operators of arbitrary length (ie like
             // "(?<=[a-z]*)") and replace with a maximum length operator
@@ -147,9 +149,9 @@ namespace octave
             size_t tmp_pos1 = new_pos + 2;
             size_t tmp_pos2 = tmp_pos1;
 
-            while (tmp_pos1 < pattern.length () && brackets > 0)
+            while (tmp_pos1 < m_pattern.length () && brackets > 0)
               {
-                char ch = pattern.at (tmp_pos1);
+                char ch = m_pattern.at (tmp_pos1);
 
                 if (ch == '(')
                   brackets++;
@@ -166,12 +168,12 @@ namespace octave
 
             if (brackets != 0)
               {
-                buf << pattern.substr (pos, new_pos - pos) << "(?";
+                buf << m_pattern.substr (pos, new_pos - pos) << "(?";
                 pos = new_pos + 2;
               }
             else
               {
-                size_t tmp_pos3 = pattern.find_first_of ("*+", tmp_pos2);
+                size_t tmp_pos3 = m_pattern.find_first_of ("*+", tmp_pos2);
 
                 if (tmp_pos3 != std::string::npos && tmp_pos3 < tmp_pos1)
                   {
@@ -181,44 +183,44 @@ namespace octave
                         (*current_liboctave_warning_with_id_handler)
                           ("Octave:regexp-lookbehind-limit",
                            "%s: arbitrary length lookbehind patterns are only supported up to length %d",
-                           who.c_str (), MAXLOOKBEHIND);
+                           m_who.c_str (), MAXLOOKBEHIND);
                       }
 
-                    buf << pattern.substr (pos, new_pos - pos) << '(';
+                    buf << m_pattern.substr (pos, new_pos - pos) << '(';
 
                     size_t i;
 
-                    if (pattern.at (tmp_pos3) == '*')
+                    if (m_pattern.at (tmp_pos3) == '*')
                       i = 0;
                     else
                       i = 1;
 
                     for (; i < max_length + 1; i++)
                       {
-                        buf << pattern.substr (new_pos, tmp_pos3 - new_pos)
+                        buf << m_pattern.substr (new_pos, tmp_pos3 - new_pos)
                             << '{' << i << '}';
-                        buf << pattern.substr (tmp_pos3 + 1,
-                                               tmp_pos1 - tmp_pos3 - 1);
+                        buf << m_pattern.substr (tmp_pos3 + 1,
+                                                 tmp_pos1 - tmp_pos3 - 1);
                         if (i != max_length)
                           buf << '|';
                       }
                     buf << ')';
                   }
                 else
-                  buf << pattern.substr (pos, tmp_pos1 - pos);
+                  buf << m_pattern.substr (pos, tmp_pos1 - pos);
 
                 pos = tmp_pos1;
               }
           }
         else
           {
-            buf << pattern.substr (pos, new_pos - pos) << "(?";
+            buf << m_pattern.substr (pos, new_pos - pos) << "(?";
             pos = new_pos + 2;
           }
 
       }
 
-    buf << pattern.substr (pos);
+    buf << m_pattern.substr (pos);
 
     // Replace NULLs with escape sequence because conversion function c_str()
     // will terminate string early at embedded NULLs.
@@ -230,22 +232,29 @@ namespace octave
     int erroffset;
 
     int pcre_options
-      = (  (options.case_insensitive () ? PCRE_CASELESS : 0)
-         | (options.dotexceptnewline () ? 0 : PCRE_DOTALL)
-         | (options.lineanchors () ? PCRE_MULTILINE : 0)
-         | (options.freespacing () ? PCRE_EXTENDED : 0));
+      = (  (m_options.case_insensitive () ? PCRE_CASELESS : 0)
+         | (m_options.dotexceptnewline () ? 0 : PCRE_DOTALL)
+         | (m_options.lineanchors () ? PCRE_MULTILINE : 0)
+         | (m_options.freespacing () ? PCRE_EXTENDED : 0)
+         | PCRE_UTF8);
 
-    data = pcre_compile (buf_str.c_str (), pcre_options,
-                         &err, &erroffset, nullptr);
+    m_data = pcre_compile (buf_str.c_str (), pcre_options,
+                           &err, &erroffset, nullptr);
 
-    if (! data)
+    if (! m_data)
       (*current_liboctave_error_handler)
-        ("%s: %s at position %d of expression", who.c_str (), err, erroffset);
+        ("%s: %s at position %d of expression", m_who.c_str (), err, erroffset);
   }
 
   regexp::match_data
   regexp::match (const std::string& buffer)
   {
+    // check if input is valid utf-8
+    const uint8_t *buf_str = reinterpret_cast<const uint8_t *> (buffer.c_str ());
+    if (octave_u8_check_wrapper (buf_str, buffer.length ()))
+      (*current_liboctave_error_handler)
+        ("%s: the input string is invalid UTF-8", m_who.c_str ());
+
     regexp::match_data retval;
 
     std::list<regexp::match_element> lst;
@@ -256,7 +265,7 @@ namespace octave
     char *nametable;
     size_t idx = 0;
 
-    pcre *re = static_cast<pcre *> (data);
+    pcre *re = static_cast<pcre *> (m_data);
 
     pcre_fullinfo (re, nullptr, PCRE_INFO_CAPTURECOUNT,  &subpatterns);
     pcre_fullinfo (re, nullptr, PCRE_INFO_NAMECOUNT, &namecount);
@@ -280,7 +289,7 @@ namespace octave
 
         int matches = pcre_exec (re, nullptr, buffer.c_str (),
                                  buffer.length (), idx,
-                                 (idx ? PCRE_NOTBOL : 0),
+                                 PCRE_NO_UTF8_CHECK | (idx ? PCRE_NOTBOL : 0),
                                  ovector, (subpatterns+1)*3);
 
         if (matches == PCRE_ERROR_MATCHLIMIT)
@@ -307,7 +316,8 @@ namespace octave
                 pe.match_limit *= 10;
                 matches = pcre_exec (re, &pe, buffer.c_str (),
                                      buffer.length (), idx,
-                                     (idx ? PCRE_NOTBOL : 0),
+                                     PCRE_NO_UTF8_CHECK
+                                     | (idx ? PCRE_NOTBOL : 0),
                                      ovector, (subpatterns+1)*3);
               }
           }
@@ -315,11 +325,11 @@ namespace octave
         if (matches < 0 && matches != PCRE_ERROR_NOMATCH)
           (*current_liboctave_error_handler)
             ("%s: internal error calling pcre_exec; "
-             "error code from pcre_exec is %i", who.c_str (), matches);
+             "error code from pcre_exec is %i", m_who.c_str (), matches);
 
         if (matches == PCRE_ERROR_NOMATCH)
           break;
-        else if (ovector[0] >= ovector[1] && ! options.emptymatch ())
+        else if (ovector[0] >= ovector[1] && ! m_options.emptymatch ())
           {
             // Zero length match.  Skip to next char.
             idx = ovector[0] + 1;
@@ -356,13 +366,13 @@ namespace octave
             if (status == PCRE_ERROR_NOMEMORY)
               (*current_liboctave_error_handler)
                 ("%s: cannot allocate memory in pcre_get_substring_list",
-                 who.c_str ());
+                 m_who.c_str ());
 
             // Must use explicit length constructor as match can contain '\0'.
             std::string match_string = std::string (*listptr, end - start + 1);
 
             string_vector tokens (pos_match);
-            string_vector named_tokens (nnames);
+            string_vector named_tokens (m_names);
             int pos_offset = 0;
             pos_match = 0;
 
@@ -384,9 +394,9 @@ namespace octave
                                 if (nidx[j] == i)
                                   {
                                     size_t len = ovector[2*i+1] - ovector[2*i];
-                                    named_tokens(named_idx(j)) =
-                                      std::string (*(listptr+i-pos_offset),
-                                                   len);
+                                    named_tokens(m_named_idx(j))
+                                      = std::string (*(listptr+i-pos_offset),
+                                                     len);
                                     break;
                                   }
                               }
@@ -416,12 +426,12 @@ namespace octave
             else
               idx = ovector[1];
 
-            if (options.once () || idx >= buffer.length ())
+            if (m_options.once () || idx >= buffer.length ())
               break;
           }
       }
 
-    retval = regexp::match_data (lst, named_pats);
+    retval = regexp::match_data (lst, m_named_pats);
 
     return retval;
   }
