@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2010-2017 John W. Eaton
-
-This file is part of Octave.
-
-Octave is free software; you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 3 of the License, or (at your
-option) any later version.
-
-Octave is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2010-2020 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -39,16 +42,16 @@ along with Octave; see the file COPYING.  If not, see
 // transforms the glob_match::glob function to be glob_match::rpl_glob,
 // which is not what we want...
 
-static bool
-single_match_exists (const std::string& file)
-{
-  octave::sys::file_stat s (file);
-
-  return s.exists ();
-}
-
 namespace octave
 {
+  static bool
+  single_match_exists (const std::string& file)
+  {
+    sys::file_stat s (file);
+
+    return s.exists ();
+  }
+
   namespace sys
   {
     bool
@@ -75,7 +78,7 @@ namespace octave
 
       int k = 0;
 
-      octave::unwind_protect frame;
+      unwind_protect frame;
 
       void *glob_info = octave_create_glob_info_struct ();
 
@@ -151,7 +154,7 @@ namespace octave
 
       int k = 0;
 
-      octave::unwind_protect frame;
+      unwind_protect frame;
 
       void *glob_info = octave_create_glob_info_struct ();
 
