@@ -1,4 +1,9 @@
-## Copyright (C) 2017-2019 Guillaume Flandin
+########################################################################
+##
+## Copyright (C) 2017-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,116 +20,82 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
-
-## -*- texinfo -*-
-## @deftypefn  {} {@var{m} =} containers.Map ()
-## @deftypefnx {} {@var{m} =} containers.Map (@var{keys}, @var{vals})
-## @deftypefnx {} {@var{m} =} containers.Map (@var{keys}, @var{vals}, @qcode{"UniformValues"}, @var{is_uniform})
-## @deftypefnx {} {@var{m} =} containers.Map (@qcode{"KeyType"}, @var{kt}, @qcode{"ValueType"}, @var{vt})
 ##
-## Create an object of the containers.Map class that stores a list of key/value
-## pairs.
-##
-## @var{keys} is an array of @emph{unique} keys for the map.  The keys can be
-## numeric scalars or strings.  The type for numeric keys may be one of
-## @qcode{"double"}, @qcode{"single"}, @qcode{"int32"}, @qcode{"uint32"},
-## @qcode{"int64"}, or @qcode{"uint64"}.  Other numeric or logical keys will
-## be converted to @qcode{"double"}.  A single string key may be entered as is.
-## Multiple string keys are entered as a cell array of strings.
-##
-## @var{vals} is an array of values for the map with the @emph{same} number
-## of elements as @var{keys}.
-##
-## When called with no input arguments a default map is created with strings
-## as the key type and @qcode{"any"} as the value type.
-##
-## The @qcode{"UniformValues"} option specifies whether the values of
-## the map must be strictly of the same type.  If @var{is_uniform} is true, any
-## values which would be added to the map are first validated to ensure they
-## are of the correct type.
-##
-## When called with @qcode{"KeyType"} and @qcode{"ValueType"} arguments, create
-## an empty map with the specified types.  The inputs @var{kt} and @var{vt} are
-## the types for the keys and values of the map respectively.  Allowed values
-## for @var{kt} are @qcode{"char"}, @qcode{"double"}, @qcode{"single"},
-## @qcode{"int32"}, @qcode{"uint32"}, @qcode{"int64"}, @qcode{"uint64"}.
-## Allowed values for @var{vt} are @qcode{"any"}, @qcode{"char"},
-## @qcode{"double"}, @qcode{"single"}, @qcode{"int32"}, @qcode{"uint32"},
-## @qcode{"int64"}, @qcode{"uint64"}, @qcode{"logical"}.
-##
-## The return value @var{m} is an object of the containers.Map class.
-## @seealso{struct}
-## @end deftypefn
-
-## -*- texinfo -*-
-## @deftypefn {} {@var{n} =} Map.Count ()
-## Return the number of key/value pairs in the map, as a uint64.
-## @end deftypefn
-##
-## @deftypefn {} {@var{type} =} Map.KeyType ()
-## Return the key type.
-##
-## Possible values are listed above when describing input variable @var{kt}.
-## @end deftypefn
-##
-## @deftypefn {} {@var{type} =} Map.ValueType ()
-## Return the value type.
-##
-## Possible values are listed above when describing input variable @var{vt}.
-## @end deftypefn
-
-## -*- texinfo -*-
-## @deftypefn {} {@var{mask} =} Map.isKey (@var{keySet})
-## Return a logical array which is true where the elements of @var{keySet} are
-## keys of the map and false otherwise.
-##
-## @var{keySet} is a cell array of keys.  If a single key is being checked, it
-## can be entered directly as a scalar value or a char vector.
-## @end deftypefn
-##
-## @deftypefn {} {@var{keys} =} Map.keys ()
-## Return the sorted list of all keys of the map as a cell vector.
-## @end deftypefn
-##
-## @deftypefn {} {@var{n} =} Map.length ()
-## Return the number of key/value pairs in the map.
-## @end deftypefn
-##
-## @deftypefn {} {} Map.remove (@var{keySet})
-## Remove the list of key/value pairs specified by a cell array of keys
-## @var{keySet} from the map.
-##
-## @var{keySet}) can also be a scalar value or a string when specifying a
-## single key.
-## @end deftypefn
-##
-## @deftypefn  {} {@var{l} =} Map.size (@var{n})
-## @deftypefnx {} {@var{sz} =} Map.size ()
-## @deftypefnx {} {@var{dim_1}, @dots{}, @var{dim_n} =} Map.size ()
-## If @var{n} is 1, return the number of key/value pairs in the map, otherwise
-## return 1.
-## Without input arguments, return vector @code{[@var{l}, 1]} where @var{l} is
-## the number of key/value pairs in the map.
-## With multiple outputs, return @code{[@var{l}, @dots{}, 1]}.
-## @end deftypefn
-##
-## @deftypefn  {} {@var{val} =} Map.values ()
-## @deftypefnx {} {@var{val} =} Map.values (@var{keySet})
-## Return the list of all the values stored in the map as a cell vector.
-##
-## If @var{keySet}, a cell array of keys is provided, the corresponding
-## values will be returned.
-## @end deftypefn
+########################################################################
 
 classdef Map < handle
 
+  ## -*- texinfo -*-
+  ## @deftypefn  {} {@var{m} =} containers.Map ()
+  ## @deftypefnx {} {@var{m} =} containers.Map (@var{keys}, @var{vals})
+  ## @deftypefnx {} {@var{m} =} containers.Map (@var{keys}, @var{vals}, @qcode{"UniformValues"}, @var{is_uniform})
+  ## @deftypefnx {} {@var{m} =} containers.Map (@qcode{"KeyType"}, @var{kt}, @qcode{"ValueType"}, @var{vt})
+  ##
+  ## Create an object of the containers.Map class that stores a list of key/value
+  ## pairs.
+  ##
+  ## @var{keys} is an array of @emph{unique} keys for the map.  The keys can be
+  ## numeric scalars or strings.  The type for numeric keys may be one of
+  ## @qcode{"double"}, @qcode{"single"}, @qcode{"int32"}, @qcode{"uint32"},
+  ## @qcode{"int64"}, or @qcode{"uint64"}.  Other numeric or logical keys will
+  ## be converted to @qcode{"double"}.  A single string key may be entered as is.
+  ## Multiple string keys are entered as a cell array of strings.
+  ##
+  ## @var{vals} is an array of values for the map with the @emph{same} number
+  ## of elements as @var{keys}.
+  ##
+  ## When called with no input arguments a default map is created with strings
+  ## as the key type and @qcode{"any"} as the value type.
+  ##
+  ## The @qcode{"UniformValues"} option specifies whether the values of
+  ## the map must be strictly of the same type.  If @var{is_uniform} is true, any
+  ## values which would be added to the map are first validated to ensure they
+  ## are of the correct type.
+  ##
+  ## When called with @qcode{"KeyType"} and @qcode{"ValueType"} arguments, create
+  ## an empty map with the specified types.  The inputs @var{kt} and @var{vt} are
+  ## the types for the keys and values of the map respectively.  Allowed values
+  ## for @var{kt} are @qcode{"char"}, @qcode{"double"}, @qcode{"single"},
+  ## @qcode{"int32"}, @qcode{"uint32"}, @qcode{"int64"}, @qcode{"uint64"}.
+  ## Allowed values for @var{vt} are @qcode{"any"}, @qcode{"char"},
+  ## @qcode{"double"}, @qcode{"single"}, @qcode{"int32"}, @qcode{"uint32"},
+  ## @qcode{"int64"}, @qcode{"uint64"}, @qcode{"logical"}.
+  ##
+  ## The return value @var{m} is an object of the containers.Map class.
+  ## @seealso{struct}
+  ## @end deftypefn
+
   properties (GetAccess = public, SetAccess = private)
+
+    ## -*- texinfo -*-
+    ## @deftypefn {} {@var{type} =} Map.KeyType ()
+    ## Return the key type.
+    ##
+    ## Possible values are listed above when describing input variable @var{kt}.
+    ## @end deftypefn
+
     KeyType   = "char";
+
+    ## -*- texinfo -*-
+    ## @deftypefn {} {@var{type} =} Map.ValueType ()
+    ## Return the value type.
+    ##
+    ## Possible values are listed above when describing input variable @var{vt}.
+    ## @end deftypefn
+
     ValueType = "any";
+
   endproperties
 
   properties (Dependent, SetAccess = protected)
+
+    ## -*- texinfo -*-
+    ## @deftypefn {} {@var{n} =} Map.Count ()
+    ## Return the number of key/value pairs in the map, as a uint64.
+    ## @end deftypefn
+
     Count = 0;
+
   endproperties
 
   properties (private)
@@ -259,11 +230,27 @@ classdef Map < handle
     endfunction
 
     function keySet = keys (this)
+
+      ## -*- texinfo -*-
+      ## @deftypefn {} {@var{keys} =} Map.keys ()
+      ## Return the sorted list of all keys of the map as a cell vector.
+      ## @end deftypefn
+
       keySet = fieldnames (this.map).';  # compatibility requires row vector
       keySet = decode_keys (this, keySet);
     endfunction
 
     function valueSet = values (this, keySet)
+
+      ## -*- texinfo -*-
+      ## @deftypefn  {} {@var{val} =} Map.values ()
+      ## @deftypefnx {} {@var{val} =} Map.values (@var{keySet})
+      ## Return the list of all the values stored in the map as a cell vector.
+      ##
+      ## If @var{keySet}, a cell array of keys is provided, the corresponding
+      ## values will be returned.
+      ## @end deftypefn
+
       if (nargin == 1)
         valueSet = struct2cell (this.map).';
       else
@@ -284,6 +271,16 @@ classdef Map < handle
     endfunction
 
     function tf = isKey (this, keySet)
+
+      ## -*- texinfo -*-
+      ## @deftypefn {} {@var{mask} =} Map.isKey (@var{keySet})
+      ## Return a logical array which is true where the elements of @var{keySet} are
+      ## keys of the map and false otherwise.
+      ##
+      ## @var{keySet} is a cell array of keys.  If a single key is being checked, it
+      ## can be entered directly as a scalar value or a char vector.
+      ## @end deftypefn
+
       if (! iscell (keySet))
         if (isnumeric (keySet) || islogical (keySet))
           keySet = num2cell (keySet);
@@ -301,6 +298,16 @@ classdef Map < handle
     endfunction
 
     function this = remove (this, keySet)
+
+      ## -*- texinfo -*-
+      ## @deftypefn {} {} Map.remove (@var{keySet})
+      ## Remove the list of key/value pairs specified by a cell array of keys
+      ## @var{keySet} from the map.
+      ##
+      ## @var{keySet}) can also be a scalar value or a string when specifying a
+      ## single key.
+      ## @end deftypefn
+
       if (! iscell (keySet))
         if (isnumeric (keySet) || islogical (keySet))
           keySet = num2cell (keySet);
@@ -318,6 +325,18 @@ classdef Map < handle
     endfunction
 
     function varargout = size (this, n)
+
+      ## -*- texinfo -*-
+      ## @deftypefn  {} {@var{l} =} Map.size (@var{n})
+      ## @deftypefnx {} {@var{sz} =} Map.size ()
+      ## @deftypefnx {} {@var{dim_1}, @dots{}, @var{dim_n} =} Map.size ()
+      ## If @var{n} is 1, return the number of key/value pairs in the map, otherwise
+      ## return 1.
+      ## Without input arguments, return vector @code{[@var{l}, 1]} where @var{l} is
+      ## the number of key/value pairs in the map.
+      ## With multiple outputs, return @code{[@var{l}, @dots{}, 1]}.
+      ## @end deftypefn
+
       c = length (this);
       if (nargin == 1)
         if (nargout <= 1)
@@ -336,6 +355,12 @@ classdef Map < handle
     endfunction
 
     function len = length (this)
+
+      ## -*- texinfo -*-
+      ## @deftypefn {} {@var{n} =} Map.length ()
+      ## Return the number of key/value pairs in the map.
+      ## @end deftypefn
+
       len = double (this.Count);
     endfunction
 
@@ -376,6 +401,9 @@ classdef Map < handle
             otherwise
               error ("containers.Map: unknown property '%s'", s(1).subs);
           endswitch
+          if (numel (s) > 1 && strcmp (s(2).type, "()") && isempty (s(2).subs))
+            s(1) = [];
+          endif
         case "()"
           if (isempty (s(1).subs))
             error ("containers.Map: no key specified");
@@ -445,9 +473,17 @@ classdef Map < handle
       ## When concatenating maps, the data type of all values must be
       ## consistent with the ValueType of the leftmost map.
       keySet = cell (1, 0);
+      keyTypes = cell (1, 0);
       for i = 1:numel (varargin)
         keySet = [keySet, keys(varargin{i})];
+        keyTypes = [keyTypes, varargin{i}.KeyType];
       endfor
+      if (numel (unique (keyTypes)) != 1)
+        if (any (strcmp (keyTypes, "char")))
+          error ("containers.Map: cannot concatenate maps with numeric and string keys");
+        endif
+        keySet = cellfun (@(x) feval (keyTypes{1}, x), keySet, "UniformOutput", false);
+      endif
       valueSet = cell (1, 0);
       for i = 1:numel (varargin)
         valueSet = [valueSet, values(varargin{i})];
@@ -482,6 +518,8 @@ classdef Map < handle
         else
           keys = cell2mat (keys);
         endif
+      elseif (! isa (keys, this.KeyType))
+        keys = feval (this.KeyType, keys);
       endif
       keys = num2hex (keys);  # Force to char matrix with single logical column
       if (cell_input)
@@ -722,6 +760,34 @@ endclassdef
 %!   assert (m.keys (), {key});
 %! endfor
 
+## Test using mixed numerical keys (subsref)
+%!test <*56594>
+%! key = [1, 2, 3];
+%! val = {"One", "Two", "Three"};
+%! types = {"double", "single", "int32", "uint32", "int64", "uint64", ...
+%!          "int8", "uint8", "int16", "uint16"};
+%! for type1 = types
+%!   type = type1{1};
+%!   k = feval (type, key);
+%!   m = containers.Map (k, val);
+%!   for type2 = [types, "logical"]
+%!     type = type2{1};
+%!     k = feval (type, key(1));
+%!     assert (m(k), "One");
+%!   endfor
+%! endfor
+
+## Test using mixed numerical keys (subsasgn)
+%!test <*56594>
+%! key = [1, 2, 3];
+%! val = {"One", "Two", "Three"};
+%! m = containers.Map(key, val);
+%! m (uint32 (1)) = "Four";
+%! assert (m.Count, uint64(3));
+%! assert (keys (m), {1, 2, 3});
+%! assert (m(1), "Four");
+%! assert (m(uint16 (1)), "Four");
+
 ## Test sort order of keys and values
 %!test
 %! key = {"d","a","b"};
@@ -747,6 +813,13 @@ endclassdef
 %! k = keys (m3);
 %! assert (numel (k), 2);
 %! assert (k, {"a", "b"});
+%! m1 = containers.Map (1, 1);
+%! m2 = containers.Map (single ([2, 3]), {2, 3});
+%! m3 = [m1, m2];
+%! assert (m3.KeyType, "double");
+%! assert (keys (m3), {1, 2, 3});
+%! m3 = [m2, m1];
+%! assert (m3.KeyType, "single");
 
 ## Test input validation
 %!error containers.Map (1,2,3)
@@ -785,9 +858,16 @@ endclassdef
 %!error <specified key .b. does not exist>
 %! m = containers.Map ("a", 1);
 %! m("b");
-%!error <specified key .2. does not exist>
-%! m = containers.Map (1, 1);
-%! m(2);
+%!test
+%! [old_fmt, old_spacing] = format ();
+%! unwind_protect
+%!   format short;
+%!   m = containers.Map (1, 1);
+%!   fail ("m(2)", "specified key <2> does not exist");
+%! unwind_protect_cleanup
+%!   format (old_fmt);
+%!   format (old_spacing);
+%! end_unwind_protect
 %!error <only '\(\)' indexing is supported>
 %! m = containers.Map ("a", 1);
 %! m{1};
@@ -795,3 +875,7 @@ endclassdef
 %! m1 = containers.Map ("KeyType", "cell", "ValueType", "any");
 %!error <unsupported ValueType>
 %! m1 = containers.Map ("KeyType", "char", "ValueType", "cell");
+%!error
+%! m1 = containers.Map (1, 1);
+%! m2 = containers.Map ("a", 2);
+%! m3 = [m1, m2];
