@@ -1,4 +1,9 @@
-## Copyright (C) 2009-2019 Kai Habel
+########################################################################
+##
+## Copyright (C) 2009-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {[@var{cx}, @var{cy}, @var{cz}, @var{v}] =} curl (@var{x}, @var{y}, @var{z}, @var{fx}, @var{fy}, @var{fz})
@@ -47,8 +54,6 @@
 ## @seealso{divergence, gradient, del2, cross}
 ## @end deftypefn
 
-## Author: Kai Habel <kai.habel@gmx.de>
-
 function varargout = curl (varargin)
 
   fidx = 1;
