@@ -1,5 +1,9 @@
-## Copyright (C) 2004-2018 David Bateman
-## Copyright (C) 2009 VZLU Prague
+########################################################################
+##
+## Copyright (C) 2004-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,42 +20,45 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} flip (@var{x})
 ## @deftypefnx {} {} flip (@var{x}, @var{dim})
-## Flip array across dimension @var{dim}.
+## Return a copy of array @var{x} flipped across dimension @var{dim}.
 ##
-## Return a copy of @var{x} flipped about the dimension @var{dim}.
-## @var{dim} defaults to the first non-singleton dimension.
-## For example:
+## If @var{dim} is unspecified it defaults to the first non-singleton
+## dimension.
+##
+## Examples:
 ##
 ## @example
-## @group
+## ## row vector
 ## flip ([1  2  3  4])
 ##       @result{}  4  3  2  1
 ##
+## ## column vector
 ## flip ([1; 2; 3; 4])
 ##       @result{}  4
 ##           3
 ##           2
 ##           1
 ##
+## ## 2-D matrix along dimension 1
 ## flip ([1 2; 3 4])
 ##       @result{}  3  4
 ##           1  2
 ##
+## ## 2-D matrix along dimension 2
 ## flip ([1 2; 3 4], 2)
 ##       @result{}  2  1
 ##           4  3
-## @end group
 ## @end example
 ##
 ## @seealso{fliplr, flipud, rot90, rotdim, permute, transpose}
 ## @end deftypefn
 
-## Author: David Bateman, Jaroslav Hajek
-
 function y = flip (x, dim)
 
   if (nargin < 1 || nargin > 2)
