@@ -1,20 +1,27 @@
-## Copyright (C) 1993-2017 John W. Eaton
+########################################################################
+##
+## Copyright (C) 1993-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} num2str (@var{x})
@@ -30,26 +37,25 @@
 ## Examples:
 ##
 ## @example
-## @group
 ## num2str (123.456)
-##      @result{} "123.46"
+##   @result{} 123.456
 ##
 ## num2str (123.456, 4)
-##      @result{} "123.5"
+##   @result{} 123.5
 ##
 ## s = num2str ([1, 1.34; 3, 3.56], "%5.1f")
-##      @result{} s =
-##         1.0  1.3
-##         3.0  3.6
+##   @result{} s =
+##        1.0  1.3
+##        3.0  3.6
 ## whos s
-##      @result{}
-##       Attr Name        Size                     Bytes  Class
-##       ==== ====        ====                     =====  =====
-##            s           2x8                         16  char
+##   @result{} Variables in the current scope:
+##         Attr Name        Size                     Bytes  Class
+##         ==== ====        ====                     =====  =====
+##              s           2x8                         16  char
+##      Total is 16 elements using 16 bytes
 ##
 ## num2str (1.234 + 27.3i)
-##      @result{} "1.234+27.3i"
-## @end group
+##   @result{} 1.234+27.3i
 ## @end example
 ##
 ## The @code{num2str} function is not very flexible.  For better control
@@ -72,8 +78,6 @@
 ## @seealso{sprintf, int2str, mat2str}
 ## @end deftypefn
 
-## Author: jwe
-
 function retval = num2str (x, arg)
 
   if (nargin != 1 && nargin != 2)
@@ -104,7 +108,7 @@ function retval = num2str (x, arg)
           ndgt = 0;  # All Inf or all zero array
         endif
 
-        if (any (x(valid) != fix (x(valid))))
+        if (ndgt > 15 || any (x(valid) != fix (x(valid))))
           ## Floating point input
           ndgt = max (ndgt + 5, 5);   # Keep at least 5 significant digits
           ndgt = min (ndgt, 16);      # Cap significant digits at 16
@@ -115,8 +119,6 @@ function retval = num2str (x, arg)
           if (any (! valid))
             ndgt = max (ndgt, 5);     # Allow space for Inf/NaN
           endif
-          ## FIXME: Integers must be masked to show only 16 significant digits
-          ##        See test case for bug #36133 below
           fmt = sprintf ("%%%d.0f", ndgt);
         endif
       else
@@ -190,6 +192,7 @@ function retval = num2str (x, arg)
 endfunction
 
 
+## Basic tests
 %!assert (num2str (123), "123")
 %!assert (num2str (1.23), "1.23")
 %!assert (num2str (123.456, 4), "123.5")
@@ -197,6 +200,7 @@ endfunction
 %!assert (num2str (1.234 + 27.3i), "1.234+27.3i")
 %!assert (num2str ([true false true]), "1  0  1")
 
+## Exceptional values
 %!assert (num2str (19440606), "19440606")
 %!assert (num2str (2^33), "8589934592")
 %!assert (num2str (-2^33), "-8589934592")
@@ -222,7 +226,7 @@ endfunction
 %! x = cat (3, m, -m);
 
 ## real case
-%!test
+%!test <*46770>
 %! y = num2str (x);
 %! assert (rows (y) == 3);
 %! assert (y, ["8  1  6 -8 -1 -6"
@@ -230,7 +234,7 @@ endfunction
 %!             "4  9  2 -4 -9 -2"]);
 
 ## complex case
-%!test
+%!test <*46770>
 %! x(1,1,2) = -8+2i;
 %! y = num2str (x);
 %! assert (rows (y) == 3);
@@ -241,16 +245,26 @@ endfunction
 ## Clear shared variables
 %!shared
 
-## FIXME: Integers greater than flintmax() - 1 should be masked to show just
-##        16 digits of precision.
-%!test <36133>
-%! assert (num2str (1e23), "100000000000000000000000");
+## Integers greater than 1e15 should switch to exponential notation
+%!assert <*36133> (num2str (1e15), "1000000000000000")
+%!assert <*36133> (num2str (1e16), "1e+16")
+## Even exact integers in IEEE notation should use exponential notation
+%!assert <*36133> (num2str(2^512), "1.34078079299426e+154")
+## Mixed integer/floating point arrays
+%!assert <*36133> (num2str ([2.1, 1e23, pi]),
+%!                 "2.1  9.999999999999999e+22      3.141592653589793")
+
+## Large integers should not switch sign when printed due to overflow
+%!assert <*36121> (num2str (2.4e9, 15), "2400000000")
 
 ## Test for extra rows generated from newlines in format
-%!assert <44864> (rows (num2str (magic (3), "%3d %3d %3d\n")), 3)
+%!assert <*44864> (rows (num2str (magic (3), "%3d %3d %3d\n")), 3)
 
-%!assert <45174> (num2str ([65 66 67], "%s"), "ABC")
+## Test that string conversion of numeric objects results in characters
+## if the numbers are within range for ASCII.
+%!assert <*45174> (num2str ([65 66 67], "%s"), "ABC")
 
+## Test input validation
 %!error num2str ()
 %!error num2str (1, 2, 3)
 %!error <X must be a numeric> num2str ({1})
