@@ -1,25 +1,31 @@
-## Copyright (C) 2006-2016 Frederick (Rick) A Niles
-##               and Søren Hauberg
+########################################################################
+##
+## Copyright (C) 2006-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {@var{in} =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
-## @deftypefnx {Function File} {[@var{in}, @var{on}] =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
+## @deftypefn  {} {@var{in} =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
+## @deftypefnx {} {[@var{in}, @var{on}] =} inpolygon (@var{x}, @var{y}, @var{xv}, @var{yv})
 ##
 ## For a polygon defined by vertex points @code{(@var{xv}, @var{yv})}, return
 ## true if the points @code{(@var{x}, @var{y})} are inside (or on the boundary)
@@ -32,12 +38,7 @@
 ## @seealso{delaunay}
 ## @end deftypefn
 
-## Author: Frederick (Rick) A Niles <niles@rickniles.com>
-## Created: 14 November 2006
-
-## Vectorized by Søren Hauberg <soren@hauberg.org>
-
-## The method for determining if a point is in in a polygon is based on
+## Algorithm: The method for determining if a point is in a polygon is based on
 ## the algorithm shown on
 ## http://local.wasp.uwa.edu.au/~pbourke/geometry/insidepoly/
 ## and is credited to Randolph Franklin.
@@ -75,7 +76,7 @@ function [in, on] = inpolygon (x, y, xv, yv)
     ## Check if (x,y) are actually on the boundary of the polygon.
     idx2 = (((yv(i) <= y & y <= yv(j)) | (yv(j) <= y & y <= yv(i)))
             & ((xv(i) <= x & x <= xv(j)) | (xv(j) <= x & x <= xv(i)))
-            & (0 == distance | !delta_xv));
+            & (0 == distance | ! delta_xv));
     on(idx2) = true;
 
     j = i;
@@ -98,13 +99,13 @@ endfunction
 %! ya = [0:0.1:1.4];
 %! [x,y] = meshgrid (xa, ya);
 %! [in,on] = inpolygon (x, y, xv, yv);
-%! inside = in & !on;
+%! inside = in & ! on;
 %!
 %! clf;
 %! plot (xv, yv);
 %! hold on;
-%! plot (x(inside), y(inside), "@g")
-%! plot (x(!in), y(!in), "@m");
+%! plot (x(inside), y(inside), "@g");
+%! plot (x(! in), y(! in), "@m");
 %! plot (x(on), y(on), "@b");
 %! hold off;
 %! disp ("Green points are inside polygon, magenta are outside,");
@@ -123,13 +124,13 @@ endfunction
 %! ya = [0:0.1:1.4];
 %! [x, y] = meshgrid (xa, ya);
 %! [in, on] = inpolygon (x, y, xv, yv);
-%! inside = in & !on;
+%! inside = in & ! on;
 %!
 %! clf;
 %! plot (xv, yv);
 %! hold on;
 %! plot (x(inside), y(inside), "@g");
-%! plot (x(!in), y(!in), "@m");
+%! plot (x(! in), y(! in), "@m");
 %! plot (x(on), y(on), "@b");
 %! hold off;
 %! disp ("Green points are inside polygon, magenta are outside,");
@@ -168,4 +169,3 @@ endfunction
 %!error <XV and YV must be real vectors> inpolygon (1, 1, [3i, 4], [5, 6])
 %!error <XV and YV must be real vectors> inpolygon (1, 1, [3, 4], {5, 6})
 %!error <XV and YV must .* the same size> inpolygon ([1,2], [3, 4], [5, 6], 1)
-
