@@ -1,26 +1,34 @@
-## Copyright (C) 2012-2017 Michael Goffioul
+########################################################################
+##
+## Copyright (C) 2012-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {} {@var{hui} =} uipushtool (@var{property}, @var{value}, @dots{})
-## @deftypefnx {} {@var{hui} =} uipushtool (@var{parent}, @var{property}, @var{value}, @dots{})
+## @deftypefn  {} {} uipushtool (@var{property}, @var{value}, @dots{})
+## @deftypefnx {} {} uipushtool (@var{parent}, @var{property}, @var{value}, @dots{})
+## @deftypefnx {} {@var{hui} =} uipushtool (@dots{})
 ##
-## Create a uipushtool object and return a handle to it.
+## Create a uipushtool object.
 ##
 ## uipushtools are buttons that appear on a figure toolbar.  The button is
 ## created with a border that is shown when the user hovers over the button.
@@ -31,13 +39,16 @@
 ## figure is available, but does not contain a uitoolbar, a uitoolbar will be
 ## created.
 ##
-## If @var{parent} is given then an uipushtools is created on the
-## @var{parent} uitoolbar.
+## If @var{parent} is given then a uipushtool is created on the @var{parent}
+## uitoolbar.
 ##
 ## Any provided property value pairs will override the default values of the
 ## created uipushtool object.
 ##
-## Uipushtool properties are documented at @ref{Uipushtool Properties}.
+## The full list of properties is documented at @ref{Uipushtool Properties}.
+##
+## The optional return value @var{hui} is a graphics handle to the created
+## uipushtool object.
 ##
 ## Examples:
 ##
@@ -56,8 +67,6 @@
 ## @seealso{figure, uitoolbar, uitoggletool}
 ## @end deftypefn
 
-## Author: goffioul
-
 function hui = uipushtool (varargin)
 
   [h, args] = __uiobject_split_args__ ("uipushtool", varargin,
@@ -70,6 +79,11 @@ function hui = uipushtool (varargin)
       h = h(1);
     endif
   endif
-  hui = __go_uipushtool__ (h, args{:});
+
+  htmp = __go_uipushtool__ (h, args{:});
+
+  if (nargout > 0)
+    hui = htmp;
+  endif
 
 endfunction
