@@ -1,4 +1,9 @@
-## Copyright (C) 2012-2019 Michael Goffioul
+########################################################################
+##
+## Copyright (C) 2012-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} uitoggletool (@var{property}, @var{value}, @dots{})
@@ -60,8 +67,6 @@
 ## @seealso{figure, uitoolbar, uipushtool}
 ## @end deftypefn
 
-## Author: goffioul
-
 function hui = uitoggletool (varargin)
 
   [h, args] = __uiobject_split_args__ ("uitoggletool", varargin,
