@@ -1,4 +1,9 @@
-## Copyright (C) 2008-2019 Soren Hauberg
+########################################################################
+##
+## Copyright (C) 2008-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{info} =} imfinfo (@var{filename})
@@ -146,8 +153,6 @@
 ## @seealso{imread, imwrite, imshow, imformats}
 ## @end deftypefn
 
-## Author: Soren Hauberg <hauberg@gmail.com>
-
 function info = imfinfo (filename, varargin)
 
   if (nargin < 1 || nargin > 2)
