@@ -1,24 +1,31 @@
-## Copyright (C) 2010, 2013 Philip Nienhuis
+########################################################################
+##
+## Copyright (C) 2010-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} javamem ()
-## @deftypefnx {Function File} {@var{jmem} =} javamem ()
+## @deftypefn  {} {} javamem ()
+## @deftypefnx {} {@var{jmem} =} javamem ()
 ## Show the current memory usage of the Java virtual machine (JVM) and run the
 ## garbage collector.
 ##
@@ -56,13 +63,6 @@
 ## Java's own cleaning up and your operating system's memory management.
 ## @end deftypefn
 
-## Author: Philip Nienhuis
-## Created: 2010-03-25
-## Updates:
-## 2010-03-26 Changed name to javamem & indentation to double spaces
-## 2010-08-25 Corrected text on java memory assignments
-## 2010-09-05 Further overhauled help text
-
 function jmem = javamem ()
 
   rt = javaMethod ("getRuntime", "java.lang.Runtime");
@@ -88,4 +88,3 @@ function jmem = javamem ()
   endif
 
 endfunction
-
