@@ -1,4 +1,9 @@
-## Copyright (C) 2016-2018 Philip Nienhuis
+########################################################################
+##
+## Copyright (C) 2016-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{mingwpath} =} __w2mpth__ (@var{winpath})
@@ -40,9 +47,6 @@
 ##
 ## @end deftypefn
 
-## Author: Philip Nienhuis <prnienhuis@users.sf.net>
-## Created: 2015-01-16
-
 function mingwpath = __w2mpth__ (winpath)
 
   ## Check for platform
