@@ -1,20 +1,27 @@
-## Copyright (C) 2004-2017 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2004-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} unix ("@var{command}")
@@ -32,14 +39,16 @@
 ## @seealso{dos, system, isunix, ismac, ispc}
 ## @end deftypefn
 
-## Author: octave-forge ???
-## Adapted by: jwe
-
 function [status, text] = unix (command, echo_arg)
 
   if (nargin < 1 || nargin > 2)
     print_usage ();
-  elseif (isunix ())
+  endif
+
+  status = 1;
+  text = "";
+
+  if (isunix ())
     [status, text] = system (command);
     if (nargin > 1 || nargout == 0)
       printf ("%s\n", text);
@@ -51,7 +60,6 @@ endfunction
 
 %!test
 %! cmd = ls_command ();
-%! warning ("off", "Octave:undefined-return-values", "local");
 %! [status, output] = unix (cmd);
 %!
 %! if (isunix ())
@@ -59,8 +67,8 @@ endfunction
 %!   assert (ischar (output));
 %!   assert (! isempty (output));
 %! else
-%!   assert (status, []);
-%!   assert (output, []);
+%!   assert (status, 1);
+%!   assert (output, "");
 %! endif
 
 %!error unix ()
