@@ -1,4 +1,9 @@
-## Copyright (C) 2006-2018 Thomas Treichl <treichl@users.sourceforge.net>
+########################################################################
+##
+## Copyright (C) 2006-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,8 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
-
-## Author: Thomas Treichl <treichl@users.sourceforge.net>
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{stop_solve} =} odeplot (@var{t}, @var{y}, @var{flag})
