@@ -1,5 +1,9 @@
-## Copyright (C) 2003-2018 Andy Adler
-## Copyright (C) 2002, 2013 N.J.Higham
+########################################################################
+##
+## Copyright (C) 2003-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,14 +20,20 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{x} =} fminsearch (@var{fun}, @var{x0})
 ## @deftypefnx {} {@var{x} =} fminsearch (@var{fun}, @var{x0}, @var{options})
-## @deftypefnx {} {@var{x} =} fminsearch (@var{fun}, @var{x0}, @var{options}, @var{fun_arg1}, @var{fun_arg2}, @dots{})
+## @deftypefnx {} {@var{x} =} fminsearch (@var{problem})
 ## @deftypefnx {} {[@var{x}, @var{fval}, @var{exitflag}, @var{output}] =} fminsearch (@dots{})
 ##
-## Find a value of @var{x} which minimizes the function @var{fun}.
+## Find a value of @var{x} which minimizes the multi-variable function
+## @var{fun}.
+##
+## @var{fun} is a function handle, inline function, or string containing the
+## name of the function to evaluate.
 ##
 ## The search begins at the point @var{x0} and iterates using the
 ## @nospell{Nelder & Mead} Simplex algorithm (a derivative-free method).  This
@@ -32,25 +42,55 @@
 ##
 ## Options for the search are provided in the parameter @var{options} using the
 ## function @code{optimset}.  Currently, @code{fminsearch} accepts the options:
-## @qcode{"TolX"}, @qcode{"TolFun"}, @qcode{"MaxFunEvals"}, @qcode{"MaxIter"},
-## @qcode{"Display"}, @qcode{"FunValCheck"}, and @qcode{"OutputFcn"}.
-## For a description of these options, see @code{optimset}.
+## @qcode{"Display"}, @qcode{"FunValCheck"},@qcode{"MaxFunEvals"},
+## @qcode{"MaxIter"}, @qcode{"OutputFcn"}, @qcode{"TolFun"}, @qcode{"TolX"}.
 ##
-## Additional inputs for the function @var{fun} can be passed as the fourth
-## and higher arguments.  To pass function arguments while using the default
-## @var{options} values, use @code{[]} for @var{options}.
+## @qcode{"MaxFunEvals"} proscribes the maximum number of function evaluations
+## before optimization is halted.  The default value is
+## @code{200 * number_of_variables}, i.e., @code{200 * length (@var{x0})}.
+## The value must be a positive integer.
+##
+## @qcode{"MaxIter"} proscribes the maximum number of algorithm iterations
+## before optimization is halted.  The default value is
+## @code{200 * number_of_variables}, i.e., @code{200 * length (@var{x0})}.
+## The value must be a positive integer.
+##
+## For a description of the other options, see @code{optimset}.  To initialize
+## an options structure with default values for @code{fminsearch} use
+## @code{options = optimset ("fminsearch")}.
+##
+## @code{fminsearch} may also be called with a single structure argument
+## with the following fields:
+##
+## @table @code
+## @item objective
+## The objective function.
+##
+## @item x0
+## The initial point.
+##
+## @item solver
+## Must be set to @qcode{"fminsearch"}.
+##
+## @item options
+## A structure returned from @code{optimset} or an empty matrix to
+## indicate that defaults should be used.
+## @end table
+##
+## @noindent
+## The field @code{options} is optional.  All others are required.
 ##
 ## On exit, the function returns @var{x}, the minimum point, and @var{fval},
 ## the function value at the minimum.
 ##
-## The third return value @var{exitflag} is
+## The third output @var{exitflag} reports whether the algorithm succeeded and
+## may take one of the following values:
 ##
 ## @table @asis
 ## @item 1
 ## if the algorithm converged
-## (size of the simplex is smaller than @code{@var{options}.TolX} @strong{AND}
-## the step in the function value between iterations is smaller than
-## @code{@var{options}.TolFun}).
+## (size of the simplex is smaller than @code{TolX} @strong{AND} the step in
+## function value between iterations is smaller than @code{TolFun}).
 ##
 ## @item 0
 ## if the maximum number of iterations or the maximum number of function
@@ -60,10 +100,11 @@
 ## if the iteration is stopped by the @qcode{"OutputFcn"}.
 ## @end table
 ##
-## The fourth return value is a structure @var{output} with the fields,
-## @code{funcCount} containing the number of function calls to @var{fun},
-## @code{iterations} containing the number of iteration steps,
-## @code{algorithm} with the name of the search algorithm (always:
+## The fourth output is a structure @var{output} containing runtime
+## about the algorithm.  Fields in the structure are @code{funcCount}
+## containing the number of function calls to @var{fun}, @code{iterations}
+## containing the number of iteration steps, @code{algorithm} with the name of
+## the search algorithm (always:
 ## @nospell{@qcode{"Nelder-Mead simplex direct search"}}), and @code{message}
 ## with the exit message.
 ##
@@ -72,6 +113,9 @@
 ## @example
 ## fminsearch (@@(x) (x(1)-5).^2+(x(2)-8).^4, [0;0])
 ## @end example
+##
+## Note: If you need to find the minimum of a single variable function it is
+## probably better to use @code{fminbnd}.
 ## @seealso{fminbnd, fminunc, optimset}
 ## @end deftypefn
 
@@ -80,22 +124,54 @@
 
 ## FIXME: Add support for output function with "state" set to "interrupt".
 
-function [x, fval, exitflag, output] = fminsearch (fun, x0, options, varargin)
+function [x, fval, exitflag, output] = fminsearch (varargin)
 
-  ## Get default options if requested.
-  if (nargin == 1 && ischar (fun) && strcmp (fun, "defaults"))
-    x = optimset ("Display", "notify", "FunValCheck", "off",
-                  "MaxFunEvals", 400, "MaxIter", 400,
-                  "OutputFcn", [],
-                  "TolFun", 1e-7, "TolX", 1e-4);
-    return;
-  endif
-
-  if (nargin < 2)
+  if (nargin < 1)
     print_usage ();
   endif
 
-  if (nargin < 3 || isempty (options))
+  ## Get default options if requested.
+  if (nargin == 1 && ischar (varargin{1}) && strcmp (varargin{1}, "defaults"))
+    x = struct ("Display", "notify", "FunValCheck", "off",
+                "MaxFunEvals", [], "MaxIter", [],
+                "OutputFcn", [],
+                "TolFun", 1e-4, "TolX", 1e-4);
+    return;
+  endif
+
+  if (nargin == 1)
+    problem = varargin{1};
+    varargin = {};
+    if (! isstruct (problem))
+      error ("fminsearch: PROBLEM must be a structure");
+    endif
+    fun = problem.objective;
+    x0 = problem.x0;
+    if (! strcmp (problem.solver, "fminsearch"))
+      error ('fminsearch: problem.solver must be set to "fminsearch"');
+    endif
+    if (isfield (problem, "options"))
+      options = problem.options;
+    else
+      options = [];
+    endif
+  elseif (nargin > 1)
+    fun = varargin{1};
+    x0 = varargin{2};
+    if (nargin > 2)
+      options = varargin{3};
+      varargin(1:3) = [];
+    else
+      options = [];
+      varargin = {};
+    endif
+  endif
+
+  if (ischar (fun))
+    fun = str2func (fun);
+  endif
+
+  if (isempty (options))
     options = struct ();
   endif
 
@@ -154,13 +230,13 @@ function [stopit, savit, dirn, trace, tol, maxiter, tol_f, outfcn] = ...
   stopit(1) = tol = optimget (options, "TolX", 1e-4);
 
   ## Tolerance for cgce test based on step in function value.
-  tol_f = optimget (options, "TolFun", 1e-7);
+  tol_f = optimget (options, "TolFun", 1e-4);
 
   ## Max number of function evaluations.
-  stopit(2) = optimget (options, "MaxFunEvals", length (x) * 200);
+  stopit(2) = optimget (options, "MaxFunEvals", 200 * length (x));
 
   ## Max number of iterations
-  maxiter = optimget (options, "MaxIter", length (x) * 200);
+  maxiter = optimget (options, "MaxIter", 200 * length (x));
 
   ## Default target for function values.
   stopit(3) = Inf;  # FIXME: expose this parameter to the outside
@@ -200,7 +276,9 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
 
   if (strcmpi (optimget (options, "FunValCheck", "off"), "on"))
     ## Replace fcn with a guarded version.
-    fun = @(x) guarded_eval (fun, x);
+    fun = @(x) guarded_eval (fun, x, varargin{:});
+  else
+    fun = @(x) real (fun (x, varargin{:}));
   endif
 
   x0 = x(:);  # Work with column vector internally.
@@ -209,12 +287,12 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
   V = [zeros(n,1) eye(n)];
   f = zeros (n+1,1);
   V(:,1) = x0;
-  f(1) = dirn * feval (fun, x, varargin{:});
+  f(1) = dirn * fun (x);
   fmax_old = f(1);
   nf = 1;
 
   if (trace == 1)
-    printf ("f(x0) = %9.4e\n", f(1));
+    printf ("f(x0) = %9.4e\n", dirn * f(1));
   endif
 
   k = 0; m = 0;
@@ -229,7 +307,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     for j = 2:n+1
       V(j-1,j) = x0(j-1) + alpha(1);
       x(:) = V(:,j);
-      f(j) = dirn * feval (fun,x,varargin{:});
+      f(j) = dirn * fun (x);
     endfor
   else
     ## Right-angled simplex based on co-ordinate axes.
@@ -237,7 +315,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     for j = 2:n+1
       V(:,j) = x0 + alpha(j)*V(:,j);
       x(:) = V(:,j);
-      f(j) = dirn * feval (fun,x,varargin{:});
+      f(j) = dirn * fun (x);
     endfor
   endif
   nf += n;
@@ -253,7 +331,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
   if (! isempty (outfcn))
     optimvalues.iteration = 0;
     optimvalues.funccount = nf;
-    optimvalues.fval = f(1);
+    optimvalues.fval = dirn * f(1);
     optimvalues.procedure = how;
     state = "init";
     stop = outfcn (x, optimvalues, state);
@@ -269,7 +347,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     k += 1;
 
     if (k > maxiter)
-      msg = "Exceeded maximum iterations...quitting\n";
+      msg = "Exceeded maximum iterations\n";
       break;
     endif
 
@@ -283,7 +361,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     if (trace == 1)
       printf ("Iter. %2.0f,", k);
       printf ("  how = %-11s", [how ","]);
-      printf ("nf = %3.0f,  f = %9.4e  (%2.1f%%)\n", nf, fmax, ...
+      printf ("nf = %3.0f,  f = %9.4e  (%2.1f%%)\n", nf, dirn * fmax, ...
               100*(fmax-fmax_old)/(abs(fmax_old)+eps));
     endif
     fmax_old = fmax;
@@ -293,14 +371,15 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     ## Stopping Test 1 - f reached target value?
     if (fmax >= stopit(3))
       msg = "Exceeded target...quitting\n";
-      ## FIXME: Add docu when stopit(3) gets exposed to the outside
+      ## FIXME: Add documentation when stopit(3) gets exposed to the outside
       exitflag = -1;
       break;
     endif
 
     ## Stopping Test 2 - too many f-evals?
     if (nf >= stopit(2))
-      msg = "Max no. of function evaluations exceeded...quitting\n";
+      msg = "Exceeded maximum number of function evaluations\n";
+      exitflag = 0;
       break;
     endif
 
@@ -309,8 +388,8 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     size_simplex = norm (V(:,2:n+1)-v1(:,ones (1,n)),1) / max (1, norm (v1,1));
     step_f = max (abs (f(1) - f(2:n+1)));
     if (size_simplex <= tol && step_f <= tol_f )
-      msg = sprintf (["Simplex size %9.4e <= %9.4e and ", ...
-                      "step in function value %9.4e <= %9.4e...quitting\n"], ...
+      msg = sprintf (["Algorithm converged.  Simplex size %9.4e <= %9.4e ", ...
+                      "and step in function value %9.4e <= %9.4e\n"], ...
                       size_simplex, tol, step_f, tol_f);
       exitflag = 1;
       break;
@@ -319,7 +398,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     ## Call OutputFcn
     if (! isempty (outfcn))
       optimvalues.funccount = nf;
-      optimvalues.fval = f(1);
+      optimvalues.fval = dirn * f(1);
       optimvalues.iteration = k;
       optimvalues.procedure = how;
       state = "iter";
@@ -339,14 +418,14 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
     vbar = (sum (V(:,1:n)')/n)';  # Mean value
     vr = (1 + alpha)*vbar - alpha*V(:,n+1);
     x(:) = vr;
-    fr = dirn * feval (fun,x,varargin{:});
+    fr = dirn * fun (x);
     nf += 1;
     vk = vr;  fk = fr; how = "reflect";
     if (fr > f(n))
       if (fr > f(1))
         ve = gamma*vr + (1-gamma)*vbar;
         x(:) = ve;
-        fe = dirn * feval (fun,x,varargin{:});
+        fe = dirn * fun (x);
         nf += 1;
         if (fe > f(1))
           vk = ve;
@@ -363,7 +442,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
       endif
       vc = beta*vt + (1-beta)*vbar;
       x(:) = vc;
-      fc = dirn * feval (fun,x,varargin{:});
+      fc = dirn * fun (x);
       nf += 1;
       if (fc > f(n))
         vk = vc; fk = fc;
@@ -372,12 +451,12 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
         for j = 2:n
           V(:,j) = (V(:,1) + V(:,j))/2;
           x(:) = V(:,j);
-          f(j) = dirn * feval (fun,x,varargin{:});
+          f(j) = dirn * fun (x);
         endfor
         nf += n-1;
         vk = (V(:,1) + V(:,n+1))/2;
         x(:) = vk;
-        fk = dirn * feval (fun,x,varargin{:});
+        fk = dirn * fun (x);
         nf += 1;
         how = "shrink";
       endif
@@ -401,7 +480,7 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
   ##        i.e., only when we have successfully converged?
   if (! isempty (outfcn))
     optimvalues.funccount = nf;
-    optimvalues.fval = f(1);
+    optimvalues.fval = dirn * f(1);
     optimvalues.iteration = k;
     optimvalues.procedure = how;
     state = "done";
@@ -417,9 +496,9 @@ function [x, exitflag, output] = nmsmax (fun, x, options, varargin)
 endfunction
 
 ## A helper function that evaluates a function and checks for bad results.
-function y = guarded_eval (fun, x)
+function y = guarded_eval (fun, x, varargin)
 
-  y = fun (x);
+  y = fun (x, varargin{:});
 
   if (! (isreal (y)))
     error ("fminsearch:notreal", "fminsearch: non-real value encountered");
@@ -452,6 +531,17 @@ endfunction
 %! x = fminsearch (@sin, 3, optimset ("MaxFunEvals", 18, "Display", "none"));
 %! assert (x, 4.7109, 1e-4);
 
+%!test
+%! problem.objective = @sin;
+%! problem.x0 = 3;
+%! problem.solver = "fminsearch";
+%! problem.options = optimset ("MaxIter", 3, "Display", "none");
+%! x = fminsearch (problem);
+%! assert (x, 4.8750, 1e-4);
+%! problem.options = optimset ("MaxFunEvals", 18, "Display", "none");
+%! x = fminsearch (problem);
+%! assert (x, 4.7109, 1e-4);
+
 %!test
 %! c = 1.5;
 %! assert (fminsearch (@(x) x(1).^2 + c*x(2).^2, [1;1]), [0;0], 1e-4);
@@ -490,4 +580,3 @@ endfunction
 ## Test input validation
 %!error fminsearch ()
 %!error fminsearch (1)
-
