@@ -1,4 +1,9 @@
-## Copyright (C) 2016-2018 Carnë Draug
+########################################################################
+##
+## Copyright (C) 2016-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {} build (@var{builddir}, @var{tarballs}, @var{verbose})
@@ -38,7 +45,7 @@ function build (builddir, tarballs, verbose)
     print_usage ();
   endif
 
-  if (! exist (builddir, "dir"))
+  if (! isfolder (builddir))
     warning ("creating build directory %s", builddir);
     [status, msg] = mkdir (builddir);
     if (status != 1)
@@ -46,7 +53,7 @@ function build (builddir, tarballs, verbose)
     endif
   endif
 
-  for i = 1:numel(tarballs)
+  for i = 1:numel (tarballs)
     filelist = unpack (tarballs{i}, builddir);
 
     ## We want the path for the package root but we can't assume that
