@@ -1,5 +1,9 @@
-## Copyright (C) 2007-2018 Michael Goffioul
-## Copyright (C) 2007-2009 David Bateman
+########################################################################
+##
+## Copyright (C) 2007-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} area (@var{y})
@@ -35,7 +41,8 @@
 ## the shading under the curve should be defined.  The default level is 0.
 ##
 ## Additional property/value pairs are passed directly to the underlying patch
-## object.
+## object. The full list of properties is documented at
+## @ref{Patch Properties}.
 ##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
@@ -137,7 +144,7 @@ function retval = __area__ (ax, x, y, bv, varargin)
   y0 = bv * ones (1, rows (y));
   y0 = zeros (1, rows (y));
   retval = [];
-  for i = 1: columns (y);
+  for i = 1: columns (y)
 
     lc = __next_line_color__ ();
 
