@@ -1,29 +1,36 @@
-## Copyright (C) 2007-2015 David Bateman
+########################################################################
+##
+## Copyright (C) 2007-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn  {Function File} {} ezsurfc (@var{f})
-## @deftypefnx {Function File} {} ezsurfc (@var{fx}, @var{fy}, @var{fz})
-## @deftypefnx {Function File} {} ezsurfc (@dots{}, @var{dom})
-## @deftypefnx {Function File} {} ezsurfc (@dots{}, @var{n})
-## @deftypefnx {Function File} {} ezsurfc (@dots{}, "circ")
-## @deftypefnx {Function File} {} ezsurfc (@var{hax}, @dots{})
-## @deftypefnx {Function File} {@var{h} =} ezsurfc (@dots{})
+## @deftypefn  {} {} ezsurfc (@var{f})
+## @deftypefnx {} {} ezsurfc (@var{fx}, @var{fy}, @var{fz})
+## @deftypefnx {} {} ezsurfc (@dots{}, @var{dom})
+## @deftypefnx {} {} ezsurfc (@dots{}, @var{n})
+## @deftypefnx {} {} ezsurfc (@dots{}, "circ")
+## @deftypefnx {} {} ezsurfc (@var{hax}, @dots{})
+## @deftypefnx {} {@var{h} =} ezsurfc (@dots{})
 ##
 ## Plot the surface and contour lines defined by a function.
 ##
@@ -32,8 +39,8 @@
 ## @code{-2*pi <= @var{x} | @var{y} <= 2*pi} with 60 points in each dimension.
 ##
 ## If three functions are passed, then plot the parametrically defined
-## function @code{[@var{fx} (@var{s}, @var{t}), @var{fy} (@var{s}, @var{t}),
-## @var{fz} (@var{s}, @var{t})]}.
+## function @code{[@var{fx}(@var{s}, @var{t}), @var{fy}(@var{s}, @var{t}),
+## @var{fz}(@var{s}, @var{t})]}.
 ##
 ## If @var{dom} is a two element vector, it represents the minimum and maximum
 ## values of both @var{x} and @var{y}.  If @var{dom} is a four element vector,
@@ -44,7 +51,7 @@
 ## If the argument @qcode{"circ"} is given, then the function is plotted over
 ## a disk centered on the middle of the domain @var{dom}.
 ##
-## If the first argument @var{hax} is an axes handle, then plot into this axis,
+## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
 ##
 ## The optional return value @var{h} is a 2-element vector with a graphics
@@ -80,7 +87,6 @@ endfunction
 
 %!demo
 %! clf;
-%! colormap ('default');
+%! colormap ("default");
 %! f = @(x,y) sqrt (abs (x .* y)) ./ (1 + x.^2 + y.^2);
 %! ezsurfc (f, [-3, 3]);
-
