@@ -1,20 +1,27 @@
-## Copyright (C) 2008-2016 David Bateman
+########################################################################
+##
+## Copyright (C) 2008-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} plotmatrix (@var{x}, @var{y})
@@ -44,16 +51,16 @@
 ## The marker to use can be changed with the @var{style} argument, that is a
 ## string defining a marker in the same manner as the @code{plot} command.
 ##
-## If the first argument @var{hax} is an axes handle, then plot into this axis,
+## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
 ##
 ## The optional return value @var{h} provides handles to the individual
 ## graphics objects in the scatter plots, whereas @var{ax} returns the
-## handles to the scatter plot axis objects.
+## handles to the scatter plot axes objects.
 ##
-## @var{bigax} is a hidden axis object that surrounds the other axes, such
+## @var{bigax} is a hidden axes object that surrounds the other axes, such
 ## that the commands @code{xlabel}, @code{title}, etc., will be associated
-## with this hidden axis.
+## with this hidden axes.
 ##
 ## Finally, @var{p} returns the graphics objects associated with the histogram
 ## and @var{pax} the corresponding axes objects.
@@ -111,6 +118,7 @@ endfunction
 %!demo
 %! clf;
 %! plotmatrix (randn (100, 3), "g+");
+%! title ("plotmatrix() demo #1");
 
 
 function plotmatrixdelete (h, d, ax)
@@ -120,7 +128,7 @@ function plotmatrixdelete (h, d, ax)
     if (isaxes (hc) && strcmpi (get (hc, "beingdeleted"), "off"))
       parent = get (hc, "parent");
       ## If the parent is invalid or being deleted, then do nothing
-      if (ishandle (parent) && strcmpi (get (parent, "beingdeleted"), "off"))
+      if (ishghandle (parent) && strcmpi (get (parent, "beingdeleted"), "off"))
         delete (hc);
       endif
     endif
@@ -203,4 +211,3 @@ function [h, ax, p, pax] = __plotmatrix__ (bigax, varargin)
   endfor
 
 endfunction
-
