@@ -1,20 +1,27 @@
-## Copyright (C) 2009-2016 Kai Habel
+########################################################################
+##
+## Copyright (C) 2009-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} surfl (@var{z})
@@ -38,13 +45,14 @@
 ##
 ## The default lighting mode @qcode{"cdata"}, changes the cdata property of the
 ## surface object to give the impression of a lighted surface.
-## @strong{Warning:} The alternative mode @qcode{"light"} mode which creates a
-## light object to illuminate the surface is not implemented (yet).
 ##
-## The light source location can be specified using @var{lsrc}.  It can be
-## given as a 2-element vector [azimuth, elevation] in degrees, or as a
-## 3-element vector [lx, ly, lz].  The default value is rotated 45 degrees
-## counterclockwise to the current view.
+## The alternate mode @qcode{"light"} creates a light object to illuminate the
+## surface.
+##
+## The light source location may be specified using @var{lsrc} which can be
+## a 2-element vector [azimuth, elevation] in degrees, or a 3-element vector
+## [lx, ly, lz].  The default value is rotated 45 degrees counterclockwise to
+## the current view.
 ##
 ## The material properties of the surface can specified using a 4-element
 ## vector @var{P} = [@var{AM} @var{D} @var{SP} @var{exp}] which defaults to
@@ -60,7 +68,7 @@
 ## @item @qcode{"EXP"} specular exponent
 ## @end table
 ##
-## If the first argument @var{hax} is an axes handle, then plot into this axis,
+## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
 ##
 ## The optional return value @var{h} is a graphics handle to the created
@@ -78,8 +86,6 @@
 ## @seealso{diffuse, specular, surf, shading, colormap, caxis}
 ## @end deftypefn
 
-## Author: Kai Habel <kai.habel@gmx.de>
-
 function h = surfl (varargin)
 
   [hax, varargin, nargin] = __plt_get_axis_arg__ ("surfl", varargin{:});
@@ -93,8 +99,6 @@ function h = surfl (varargin)
   if (ischar (varargin{end}))
     switch (tolower (varargin{end}))
       case "light"
-        warning ("surfl: light method not supported (yet), using cdata method instead");
-        ## This can be implemented when light objects are supported.
         use_cdata = false;
       case "cdata"
         use_cdata = true;
@@ -110,7 +114,8 @@ function h = surfl (varargin)
   ##      diffuse reflection strength,
   ##      specular reflection strength,
   ##      specular shine]
-  if (isnumeric (varargin{end}) && length (varargin{end}) == 4)
+  if (isnumeric (varargin{end}) && isvector (varargin{end})
+      && (numel (varargin{end}) == 4))
     r = varargin{end};
     varargin(end) = [];
   else
@@ -120,7 +125,7 @@ function h = surfl (varargin)
 
   ## Check for light vector (lv) argument.
   have_lv = false;
-  if (isnumeric (varargin{end}))
+  if (isnumeric (varargin{end}) && isvector (varargin{end}))
     len = numel (varargin{end});
     lastarg = varargin{end};
     if (len == 3)
@@ -146,7 +151,7 @@ function h = surfl (varargin)
     htmp = surface (varargin{:});
     if (! ishold ())
       set (hax, "view", [-37.5, 30],
-                "xgrid", "on", "ygrid", "on", "zgrid", "on", "clim", [0 1]);
+                "xgrid", "on", "ygrid", "on", "zgrid", "on");
     endif
 
     ## Get view vector (vv).
@@ -162,23 +167,32 @@ function h = surfl (varargin)
       lv = (R * vv.').';
     endif
 
-    vn = get (htmp, "vertexnormals");
-    dar = get (hax, "dataaspectratio");
-    vn(:,:,1) *= dar(1);
-    vn(:,:,2) *= dar(2);
-    vn(:,:,3) *= dar(3);
+    if (use_cdata)
+      set (hax, "clim", [0 1]);
 
-    ## Normalize vn.
-    vn ./= repmat (sqrt (sumsq (vn, 3)), [1, 1, 3]);
-    [nr, nc] = size (get (htmp, "zdata"));
+      __update_normals__ (htmp);
+      vn = get (htmp, "vertexnormals");
+      dar = get (hax, "dataaspectratio");
+      vn(:,:,1) *= dar(1);
+      vn(:,:,2) *= dar(2);
+      vn(:,:,3) *= dar(3);
 
-    ## Ambient, diffuse, and specular term.
-    cdata = (  r(1) * ones (nr, nc)
-             + r(2) * diffuse  (vn(:,:,1), vn(:,:,2), vn(:,:,3), lv)
-             + r(3) * specular (vn(:,:,1), vn(:,:,2), vn(:,:,3), lv, vv, r(4)));
-    cdata ./= sum (r(1:3));
+      ## Normalize vn.
+      vn ./= repmat (sqrt (sumsq (vn, 3)), [1, 1, 3]);
+      [nr, nc] = size (get (htmp, "zdata"));
 
-    set (htmp, "cdata", cdata);
+      ## Ambient, diffuse, and specular term.
+      cdata = (  r(1) * ones (nr, nc)
+               + r(2) * diffuse  (vn(:,:,1), vn(:,:,2), vn(:,:,3), lv)
+               + r(3) * specular (vn(:,:,1), vn(:,:,2), vn(:,:,3), lv, vv, r(4)));
+      cdata ./= sum (r(1:3));
+
+      set (htmp, "cdata", cdata);
+    else
+      light (hax, "position", lv);
+      set (htmp, "ambientstrength", r(1), "diffusestrength", r(2), ...
+                 "specularstrength", r(3), "specularexponent", r(4));
+    endif
 
   unwind_protect_cleanup
     if (! isempty (oldfig))
@@ -209,3 +223,10 @@ endfunction
 %! shading interp;
 %! title ("surfl() with lighting vector and material properties");
 
+%!demo
+%! clf;
+%! [X, Y] = meshgrid (-3:1/8:3);
+%! Z = peaks (X, Y);
+%! surfl (X, Y, Z, "light");
+%! shading interp;
+%! title ("surfl() with light object");
