@@ -1,4 +1,9 @@
-## Copyright (C) 2007-2019 David Bateman
+########################################################################
+##
+## Copyright (C) 2007-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} surfnorm (@var{x}, @var{y}, @var{z})
@@ -34,7 +41,8 @@
 ## If no return arguments are requested, a surface plot with the normal
 ## vectors to the surface is plotted.
 ##
-## Any property/value input pairs are assigned to the surface object.
+## Any property/value input pairs are assigned to the surface object.  The full
+## list of properties is documented at @ref{Surface Properties}.
 ##
 ## If the first argument @var{hax} is an axes handle, then plot into this axes,
 ## rather than the current axes returned by @code{gca}.
