@@ -1,4 +1,9 @@
-## Copyright (C) 2007-2019 Ben Abbott
+########################################################################
+##
+## Copyright (C) 2007-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {@var{h} =} findobj ()
@@ -86,8 +93,6 @@
 ## @seealso{findall, allchild, get, set}
 ## @end deftypefn
 
-## Author: Ben Abbott <bpabbott@mac.com>
-
 function h = findobj (varargin)
 
   depth = NaN;
