@@ -1,26 +1,33 @@
-## Copyright (C) 2005-2016 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2005-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{h} =} gca ()
-## Return a handle to the current axis object.
+## Return a handle to the current axes object.
 ##
-## The current axis is the default target for graphics output.  In the case
+## The current axes is the default target for graphics output.  In the case
 ## of a figure with multiple axes, @code{gca} returns the last created axes
 ## or the last axes that was clicked on with the mouse.
 ##
@@ -39,7 +46,7 @@
 ## creates an empty axes object and then changes its location and size in the
 ## figure window.
 ##
-## Note: To find the current axis without creating a new axes object if it
+## Note: To find the current axes without creating a new axes object if it
 ## does not exist, query the @qcode{"CurrentAxes"} property of a figure.
 ##
 ## @example
@@ -48,8 +55,6 @@
 ## @seealso{gcf, gco, gcbf, gcbo, get, set}
 ## @end deftypefn
 
-## Author: jwe
-
 function h = gca ()
 
   if (nargin == 0)
@@ -72,4 +77,3 @@ endfunction
 %! unwind_protect_cleanup
 %!   close (hf);
 %! end_unwind_protect
-
