@@ -1,4 +1,9 @@
-## Copyright (C) 2008-2018 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2008-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {[@var{prog}, @var{args}] =} gnuplot_binary ()
@@ -29,8 +36,6 @@
 ## @seealso{graphics_toolkit}
 ## @end deftypefn
 
-## Author: jwe
-
 function [prog, args] = gnuplot_binary (new_prog, varargin)
 
   mlock ();
@@ -62,11 +67,14 @@ endfunction
 
 %!test
 %! [orig_val, orig_args] = gnuplot_binary ();
-%! [old_val, old_args] = gnuplot_binary ("__foobar__", "-opt1");
-%! assert (orig_val, old_val);
-%! assert (orig_args, old_args);
-%! assert (gnuplot_binary (), "__foobar__");
-%! [~, new_args] = gnuplot_binary ();
-%! assert (new_args, {"-opt1"});
-%! gnuplot_binary (orig_val, orig_args{:});
+%! unwind_protect
+%!   [old_val, old_args] = gnuplot_binary ("__foobar__", "-opt1");
+%!   assert (orig_val, old_val);
+%!   assert (orig_args, old_args);
+%!   assert (gnuplot_binary (), "__foobar__");
+%!   [~, new_args] = gnuplot_binary ();
+%!   assert (new_args, {"-opt1"});
+%! unwind_protect_cleanup
+%!   gnuplot_binary (orig_val, orig_args{:});
+%! end_unwind_protect
 %! assert (gnuplot_binary (), orig_val);
