@@ -1,20 +1,27 @@
-## Copyright (C) 2007-2016 Ben Abbott
+########################################################################
+##
+## Copyright (C) 2007-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {[@var{multp}, @var{idxp}] =} mpoles (@var{p})
@@ -48,9 +55,6 @@
 ## @seealso{residue, poly, roots, conv, deconv}
 ## @end deftypefn
 
-## Author: Ben Abbott <bpabbott@mac.com>
-## Created: Sept 30, 2007
-
 function [multp, indx] = mpoles (p, tol, reorder)
 
   if (nargin < 1 || nargin > 3)
@@ -84,7 +88,7 @@ function [multp, indx] = mpoles (p, tol, reorder)
     ordr = 1:Np;
   endif
 
-  ## Find pole multiplicty by comparing the relative differnce in the
+  ## Find pole multiplicity by comparing the relative difference in the
   ## poles.
 
   multp = zeros (Np, 1);
@@ -120,4 +124,3 @@ endfunction
 %!test
 %! [mp, n] = mpoles ([0 0], 0.01);
 %! assert (mp, [1; 2]);
-
