@@ -1,5 +1,9 @@
-## Copyright (C) 1993-2018 John W. Eaton
-## Copyright (C) 2009 VZLU Prague
+########################################################################
+##
+## Copyright (C) 1993-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -16,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn  {} {} toeplitz (@var{c})
@@ -57,8 +63,6 @@
 ## @seealso{hankel}
 ## @end deftypefn
 
-## Author: jwe && jh
-
 function retval = toeplitz (c, r)
 
   if (nargin < 1 || nargin > 2)
