@@ -1,20 +1,27 @@
-## Copyright (C) 2000-2016 Paul Kienzle
+########################################################################
+##
+## Copyright (C) 2000-2020 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
+## Octave is free software: you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {t =} now ()
@@ -28,10 +35,6 @@
 ## @seealso{clock, date, datenum}
 ## @end deftypefn
 
-## Author: pkienzle <pkienzle@users.sf.net>
-## Created: 10 October 2001 (CVS)
-## Adapted-By: William Poetra Yoga Hadisoeseno <williampoetra@gmail.com>
-
 function t = now ()
 
   if (nargin != 0)
@@ -47,7 +50,7 @@ function t = now ()
   ##   t = (time - mktime(gmtime(0)))/86400 + 719529;
   ##
   ## mktime (gmtime (0)) does indeed return the offset from Greenwich to the
-  ## local time zone, but we need to account for daylight savings time
+  ## local time zone, but we need to account for daylight saving time
   ## changing by an hour the offset from CUT for part of the year.
 
 endfunction
@@ -58,4 +61,3 @@ endfunction
 %!assert (now () <= now ())
 
 %!error now (1)
-
