@@ -61,6 +61,7 @@
 #  endif
 #else
 #  include "mkostemps-wrapper.h"
+#  include "uniconv-wrappers.h"
 #  include "unistd-wrappers.h"
 #  include "wait-wrappers.h"
 #endif
@@ -89,6 +90,14 @@ octave_mkostemps_wrapper (char *tmpl, int suffixlen)
   return mkostemps (tmpl, suffixlen, 0);
 }
 
+static char *
+octave_u8_conv_to_encoding (const char *tocode, const uint8_t *src,
+                            size_t srclen, size_t *lengthp)
+{
+  // FIXME: Do we need to provide the conversion here?
+  return nullptr;
+}
+
 static int
 octave_unlink_wrapper (const char *nm)
 {
@@ -147,6 +156,20 @@ quote_path (const std::string& s)
     return s;
 }
 
+static std::string
+replace_prefix (std::string s)
+{
+  const std::string match = "${prefix}";
+  size_t pos = s.find (match);
+  while (pos != std::string::npos )
+    {
+      s.replace(pos, match.length (), prepend_octave_exec_home (""));
+      pos = s.find (match);
+    }
+
+  return s;
+}
+
 static void
 initialize (void)
 {
@@ -229,7 +252,8 @@ initialize (void)
   if (vars["LIBDIR"] != "/usr/lib")
     DEFAULT_LDFLAGS += " -L" + quote_path (vars["LIBDIR"]);
 
-  vars["CPPFLAGS"] = get_variable ("CPPFLAGS", %OCTAVE_CONF_CPPFLAGS%);
+  vars["CPPFLAGS"] = get_variable ("CPPFLAGS",
+                                   replace_prefix (%OCTAVE_CONF_CPPFLAGS%));
 
   vars["INCFLAGS"] = get_variable ("INCFLAGS", DEFAULT_INCFLAGS);
 
@@ -285,19 +309,22 @@ initialize (void)
 
   vars["BLAS_LIBS"] = get_variable ("BLAS_LIBS", %OCTAVE_CONF_BLAS_LIBS%);
 
-  vars["FFTW3_LDFLAGS"] = get_variable ("FFTW3_LDFLAGS",
-                                        %OCTAVE_CONF_FFTW3_LDFLAGS%);
+  vars["FFTW3_LDFLAGS"]
+    = get_variable ("FFTW3_LDFLAGS",
+                    replace_prefix (%OCTAVE_CONF_FFTW3_LDFLAGS%));
 
   vars["FFTW3_LIBS"] = get_variable ("FFTW3_LIBS", %OCTAVE_CONF_FFTW3_LIBS%);
 
-  vars["FFTW3F_LDFLAGS"] = get_variable ("FFTW3F_LDFLAGS",
-                                         %OCTAVE_CONF_FFTW3F_LDFLAGS%);
+  vars["FFTW3F_LDFLAGS"]
+    = get_variable ("FFTW3F_LDFLAGS",
+                    replace_prefix (%OCTAVE_CONF_FFTW3F_LDFLAGS%));
 
   vars["FFTW3F_LIBS"] = get_variable ("FFTW3F_LIBS", %OCTAVE_CONF_FFTW3F_LIBS%);
 
   vars["LIBS"] = get_variable ("LIBS", %OCTAVE_CONF_LIBS%);
 
-  vars["FLIBS"] = get_variable ("FLIBS", %OCTAVE_CONF_FLIBS%);
+  vars["FLIBS"] = get_variable ("FLIBS",
+                                replace_prefix (%OCTAVE_CONF_FLIBS%));
 
   vars["OCTAVE_LINK_DEPS"] = get_variable ("OCTAVE_LINK_DEPS",
                                            %OCTAVE_CONF_MKOCTFILE_OCTAVE_LINK_DEPS%);
@@ -308,15 +335,17 @@ initialize (void)
   vars["OCT_LINK_DEPS"] = get_variable ("OCT_LINK_DEPS",
                                         %OCTAVE_CONF_MKOCTFILE_OCT_LINK_DEPS%);
 
-  vars["OCT_LINK_OPTS"] = get_variable ("OCT_LINK_OPTS",
-                                        %OCTAVE_CONF_OCT_LINK_OPTS%);
+  vars["OCT_LINK_OPTS"]
+    = get_variable ("OCT_LINK_OPTS",
+                    replace_prefix (%OCTAVE_CONF_OCT_LINK_OPTS%));
 
-  vars["LDFLAGS"] = get_variable ("LDFLAGS", %OCTAVE_CONF_LDFLAGS%);
+  vars["LDFLAGS"] = get_variable ("LDFLAGS",
+                                  replace_prefix (%OCTAVE_CONF_LDFLAGS%));
 
   vars["LD_STATIC_FLAG"] = get_variable ("LD_STATIC_FLAG",
                                          %OCTAVE_CONF_LD_STATIC_FLAG%);
 
-  // FIXME: Remove LFLAGS in Octave 7.0
+  // FIXME: Remove LFLAGS in Octave 8.0
   vars["LFLAGS"] = get_variable ("LFLAGS", DEFAULT_LDFLAGS);
   if (vars["LFLAGS"] != DEFAULT_LDFLAGS)
     std::cerr << "warning: LFLAGS is deprecated and will be removed in a future version of Octave, use LDFLAGS instead" << std::endl;
@@ -899,8 +928,33 @@ main (int argc, char **argv)
                + vars["CPPFLAGS"] + ' ' + vars["ALL_CFLAGS"] + ' '
                + incflags  + ' ' + defs + ' ' + quote_path (f));
 
+          // FIXME: Use wide character API for popen on Windows.
           FILE *fd = popen (cmd.c_str (), "r");
+
+#if defined (OCTAVE_USE_WINDOWS_API)
+          // FIXME: liboctinterp isn't linked in to mkoctfile.
+          // So we cannot use octave::sys::ofstream. Instead we fall back
+          // on using the functions available from libwrappers.
+          size_t srclen = dfile.length ();
+          const uint8_t *src = reinterpret_cast<const uint8_t *>
+                               (dfile.c_str ());
+
+          size_t length = 0;
+          wchar_t *wchar = reinterpret_cast<wchar_t *>
+                           (octave_u8_conv_to_encoding ("wchar_t", src, srclen,
+                                                        &length));
+
+          std::ofstream fo;
+          if (wchar != nullptr)
+            {
+              fo.open (wchar);
+              free (static_cast<void *> (wchar));
+            }
+          else
+            fo.open (dfile.c_str ());
+#else
           std::ofstream fo (dfile.c_str ());
+#endif
           size_t pos;
           while (! feof (fd))
             {
@@ -933,8 +987,33 @@ main (int argc, char **argv)
                + vars["CPPFLAGS"] + ' ' + vars["ALL_CXXFLAGS"] + ' '
                + incflags  + ' ' + defs + ' ' + quote_path (f));
 
+          // FIXME: Use wide character API for popen on Windows.
           FILE *fd = popen (cmd.c_str (), "r");
+
+#if defined (OCTAVE_USE_WINDOWS_API)
+          // FIXME: liboctinterp isn't linked in to mkoctfile.
+          // So we cannot use octave::sys::ofstream. Instead we fall back
+          // on using the functions available from libwrappers.
+          size_t srclen = dfile.length ();
+          const uint8_t *src = reinterpret_cast<const uint8_t *>
+                               (dfile.c_str ());
+
+          size_t length = 0;
+          wchar_t *wchar = reinterpret_cast<wchar_t *>
+                           (octave_u8_conv_to_encoding ("wchar_t", src, srclen,
+                                                        &length));
+
+          std::ofstream fo;
+          if (wchar != nullptr)
+            {
+              fo.open (wchar);
+              free (static_cast<void *> (wchar));
+            }
+          else
+            fo.open (dfile.c_str ());
+#else
           std::ofstream fo (dfile.c_str ());
+#endif
           size_t pos;
           while (! feof (fd))
             {
@@ -1101,9 +1180,9 @@ main (int argc, char **argv)
           std::string cmd
             = (vars["CXXLD"] + ' ' + vars["CPPFLAGS"] + ' '
                + vars["ALL_CXXFLAGS"] + ' ' + vars["RDYNAMIC_FLAG"] + ' '
-               + vars["ALL_LDFLAGS"] + ' ' + pass_on_options + ' '
-               + output_option + ' ' + objfiles + ' ' + libfiles + ' '
-               + ldflags + ' ' + vars["LFLAGS"] + ' ' + octave_libs + ' '
+               + pass_on_options + ' ' + output_option + ' ' + objfiles + ' '
+               + libfiles + ' ' + vars["ALL_LDFLAGS"] + ' ' + ldflags + ' '
+               + vars["LFLAGS"] + ' ' + octave_libs + ' '
                + vars["OCTAVE_LINK_OPTS"] + ' ' + vars["OCTAVE_LINK_DEPS"]);
 
           int status = run_command (cmd, printonly);
@@ -1130,8 +1209,8 @@ main (int argc, char **argv)
 
       std::string cmd
         = (vars["CXXLD"] + ' ' + vars["ALL_CXXFLAGS"] + ' '
-           + vars["DL_LDFLAGS"] + ' ' + vars["LDFLAGS"] + ' ' + pass_on_options
-           + " -o " + octfile + ' ' + objfiles + ' ' + libfiles + ' '
+           + pass_on_options + " -o " + octfile + ' ' + objfiles + ' '
+           + libfiles + ' ' + vars["DL_LDFLAGS"] + ' ' + vars["LDFLAGS"] + ' '
            + ldflags + ' ' + vars["LFLAGS"] + ' ' + octave_libs + ' '
            + vars["OCT_LINK_OPTS"] + ' ' + vars["OCT_LINK_DEPS"]);
 
